#
# WiKicker
#
#  DRCommand.t
#
#
# Copyright (C) 2004,2005 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: DRCommand.t,v 1.5 2005/03/28 13:23:21 naney Exp $
#
#

use strict;
use Test::More tests => 171;
BEGIN { use_ok('WiKicker::DikiCGI::RequestCommand'); }

sub test_command {
  my ($path, $type, $range_type, $range, $name, $format) = @_;

  my $command = WiKicker::DikiCGI::RequestCommand->new(path_info => $path);
  is($command->type,       $type,       "type:$path") or diag "type:$path";
  is($command->range_type, $range_type, "range_type:$path")
                                                   or diag "range_type:$path";
  is($command->range,      $range,      "range:$path") or diag "range:$path";
  is($command->name,       $name,       "name:$path") or diag "name:$path";
  is($command->format,     $format,     "format:$path")
                                                   or diag "format:$path";
}

#=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
#    /d/
#-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
test_command('',           'd', 'recent', 'recent', '', 'html');
test_command('/',          'd', 'recent', 'recent', '', 'html');
test_command('/d',         'd', 'recent', 'recent', '', 'html');
test_command('/d.html',    'd', 'recent', 'recent', '', 'html');
test_command('/d/',        'd', 'recent', 'recent', '', 'html');
test_command('/d/rss.rdf', 'd', 'recent', 'recent', '', 'rss');

test_command('/d/2004-01-01.html', 'd', 'day', '2004-01-01', '', 'html');
test_command('/d/2004-01-01:2004-01-05.html',
             'd', 'day-to-day', '2004-01-01:2004-01-05', '', 'html');
test_command('/d/2004-01-05:2004-01-01.html',
             'd', 'day-to-day', '2004-01-05:2004-01-01', '', 'html');
test_command('/d/2004-01-05:5-.html',
             'd', 'day-to', '2004-01-05:5-', '', 'html');
test_command('/d/2004-01-05:-5.html',
             'd', 'day-from', '2004-01-05:-5', '', 'html');
test_command('/d/2004-01-a.html', 'd', 'ten-day', '2004-01-a', '', 'html');
test_command('/d/2004-01-b.html', 'd', 'ten-day', '2004-01-b', '', 'html');
test_command('/d/2004-01-c.html', 'd', 'ten-day', '2004-01-c', '', 'html');
test_command('/d/2004-01-05-1.html',
             'd', 'article', '2004-01-05-1', '', 'html');

test_command('/d/01-01.html', 'd', 'month-day', '01-01', '', 'html');

#=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
#    /dw/
#-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
test_command('/dw/keyword.html', 'd', 'recent', 'recent', 'keyword', 'html');

#=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
#    /drw/
#-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
test_command('/drw/2004-01-a/keyword.html',
             'd', 'ten-day', '2004-01-a', 'keyword', 'html');

#=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
#    /dk/
#-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
test_command('/dk/keyword.html', 'dk', 'recent', 'recent', 'keyword', 'html');

#=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
#    /dkr/
#-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
test_command('/dkr/2003-01-a/keyword.html', 'dk', 'ten-day', '2003-01-a', 'keyword', 'html');


#=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
#    /t/
#-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
test_command('/t', 't', 'recent', 'recent', '', 'html');
test_command('/t/', 't', 'recent', 'recent', '', 'html');

test_command('/t.html', 't', 'recent', 'recent', '', 'html');

test_command('/t/2003-01-a.html', 't', 'ten-day', '2003-01-a', '', 'html');

#=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
#    /tw/
#-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
test_command('/tw/keyword.html', 't', 'recent', 'recent', 'keyword', 'html');

#=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
#    /trw/
#-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
test_command('/trw/2003-01-a/keyword.html', 't', 'ten-day', '2003-01-a', 'keyword', 'html');

#=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
#    /tk/
#-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
test_command('/tk/keyword.html', 'tk', 'recent', 'recent', 'keyword', 'html');

#=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
#    /tkr/
#-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
test_command('/tkr/2003-01-a/keyword.html', 'tk', 'ten-day', '2003-01-a', 'keyword', 'html');

#=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
#    /k/
#-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
test_command('/k', 'k', 'recent', 'recent', '', 'html');
test_command('/k/', 'k', 'recent', 'recent', '', 'html');
test_command('/k.html', 'k', 'recent', 'recent', '', 'html');
test_command('/k/keyword.html', 'k', 'no', 'no', 'keyword', 'html');

#=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
#    /w
#-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
test_command('/w', 'w', 'no', 'no', '', 'html');
test_command('/w/', 'w', 'no', 'no', '', 'html');
