#
# WiKicker
#
#  Datetime.t
#
#
# Copyright (C) 2003,2004,2005 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: Datetime.t,v 1.9 2005/01/09 09:48:35 naney Exp $
#
#

use strict;
use Test;

BEGIN { plan tests => 21 }

use WiKicker::WRI::Factory;
use WiKicker::WRI::Resolver;
use WiKicker::WikiPage::Env;

my $factory = WiKicker::WRI::Factory->new;

my $resolver = WiKicker::WRI::Resolver->new;
my $wri_env = WiKicker::WikiPage::HtmlEnv->new(resolver => $resolver,
                                      wikicker_url => '/wiki',
                                      localizer => undef,
                                      );

# before year
{
  my $wri = $factory->create_wri('datetime:2003-01-01T00:00:00Z');
  ok(ref $wri eq 'WiKicker::WRI::Datetime');
  ok($wri->to_html('', $wri_env),
     qq(<span class="date"><span title="2003年01月01日(水) 00:00:00 (GMT)">2003年01月01日(<span class="Wednesday">水</span>)00:00</span></span>));
  #ok($wri->to_subject_string($wri_env), '2003年01月01日(水) 00:00:00 (GMT)');
  ok($wri->to_subject_string($wri_env), 'Wed Jan 01 00:00:00 GMT 2003');
}

# last year
{
  my $wri = $factory->create_wri('datetime:2004-01-01T00:00:00Z');
  ok(ref $wri eq 'WiKicker::WRI::Datetime');
  ok($wri->to_html('', $wri_env),
     qq(<span class="date"><span title="2004年01月01日(木) 00:00:00 (GMT)">2004年01月01日(<span class="Thursday">木</span>)00:00</span></span>));
  #ok($wri->to_subject_string($wri_env), '01月01日(木) 00:00:00 (GMT)');
  ok($wri->to_subject_string($wri_env), 'Thu Jan 01 00:00:00 GMT 2004');
}

# this year
{
  my $wri = $factory->create_wri('datetime:2005-01-01T00:00:00Z');
  ok(ref $wri eq 'WiKicker::WRI::Datetime');
  ok($wri->to_html('', $wri_env),
     qq(<span class="date"><span title="2005年01月01日(土) 00:00:00 (GMT)">01月01日(<span class="Saturday">土</span>)00:00</span></span>));
  #ok($wri->to_subject_string($wri_env), '01月01日(木) 00:00:00 (GMT)');
  ok($wri->to_subject_string($wri_env), 'Sat Jan 01 00:00:00 GMT');
}


{
  my $wri = $factory->create_wri('datetime:2003-01-33T00:00:00Z');
  ok(ref $wri eq 'WiKicker::WRI::Datetime');
  my $html = $wri->to_html('', $wri_env);
  ok($html eq qq(datetime:2003-01-33T00:00:00Z));
  my $text = $wri->to_subject_string($wri_env);
  ok($text eq '2003-01-33T00:00:00Z');
}

{
  my $wri = $factory->create_wri('datetime:2003-01-01');
  ok(ref $wri eq 'WiKicker::WRI::Datetime');
  my $html = $wri->to_html('', $wri_env);
  ok($html,
     qq(<span class="date"><span title="2003年01月01日(水)">2003年01月01日(<span class="Wednesday">水</span>)</span></span>));
  #ok($wri->to_subject_string($wri_env), '2003年01月01日(水)');
  ok($wri->to_subject_string($wri_env), 'Wed Jan 01 2003');
}

{
  my $wri = $factory->create_wri('datetime:2003-01-33');
  ok(ref $wri eq 'WiKicker::WRI::Datetime');
  my $html = $wri->to_html('', $wri_env);
  ok($html, qq(<span class="date">2003-01-33</span>));
  my $text = $wri->to_subject_string($wri_env);
  ok($text, '2003-01-33');
}

{
  my $wri = $factory->create_wri('datetime:2004-02-29T12:20:51Z');
  ok(ref $wri eq 'WiKicker::WRI::Datetime');
  my $html = $wri->to_html('', $wri_env);
  ok($html,
     qq(<span class="date"><span title="2004年02月29日(日) 12:20:51 (GMT)">2004年02月29日(<span class="Sunday">日</span>)12:20</span></span>));
  #ok($wri->to_subject_string($wri_env), '02月29日(日) 12:20:51 (GMT)');
  ok($wri->to_subject_string($wri_env), 'Sun Feb 29 12:20:51 GMT 2004');
}
