#
# WiKicker
#
#  DikiDataManager.t
#
#
# Copyright (C) 2004,2005 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: DikiDataManager.t,v 1.4 2005/04/04 14:03:20 naney Exp $
#
#

use strict;

use Test::More;
BEGIN {
  eval "use DB_File::Lock";
  if ($@) {
    plan skip_all => "Can't use DB_File::Lock";
    exit;
  }
  else {
    plan tests => 56;
  }
}

use File::Path;
use WiKicker::Diki::DataManager;
use WiKicker::DikiCGI::Configuration;
use WiKicker::DikiCGI::Environment;
use Log::Log4perl qw(:easy);
Log::Log4perl->easy_init({
                          #level => $DEBUG,
                          level => $ERROR,
                          # layout => '[%p]%c: %m %n'
                          layout => '[%p] %m %n'
                         });

BEGIN {
  rmtree(['t/tmp/DikiDataManagerTest'], 0);
}

#=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
#    new
#-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
# without param
{
  eval {
    my $manager = WiKicker::Diki::DataManager->new;
  };
  if ($@) {
    ok(1);
  }
  else {
    ok(0);
  }
}

{
  eval {
    my $manager = WiKicker::Diki::DataManager
      ->new(directory => 't/tmp/DikiDataManagerTest');
  };
  if ($@) {
    ok(1);
  }
  else {
    ok(0);
  }
}

#=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
#    new
#-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
# no primary directory
{
  my $configuration = WiKicker::DikiCGI::Configuration->new;
  my $env = WiKicker::DikiCGI::Environment->new(configuration => $configuration);
  eval {
    my $manager = WiKicker::Diki::DataManager
      ->new(directory => 't/tmp/DikiDataManagerTest', environment => $env);
  };
  if ($@) {
    ok(1);
  }
  else {
    ok(0);
  }

}

#=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
#    empty
#-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
{
  mkpath(['t/tmp/DikiDataManagerTest/primary']);

  my $configuration = WiKicker::DikiCGI::Configuration->new;
  my $env = WiKicker::DikiCGI::Environment->new(configuration => $configuration);
  my $manager = WiKicker::Diki::DataManager
    ->new(directory => 't/tmp/DikiDataManagerTest', environment => $env);

  # properties
  is($manager->directory, 't/tmp/DikiDataManagerTest');
  is($manager->primary_directory, 't/tmp/DikiDataManagerTest/primary');
  is($manager->secondary_directory, 't/tmp/DikiDataManagerTest/secondary');
  ok(defined($manager->primary));
  ok(defined($manager->secondary));

  ok(-d $manager->secondary_directory);

  my $diary_day_list = $manager->get_recent_diaries(5);
  is($diary_day_list->size, 0);
}

#=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
#    empty
#-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
# create year dir
{
  mkpath(['t/tmp/DikiDataManagerTest/primary/2004']);

  my $configuration = WiKicker::DikiCGI::Configuration->new;
  my $env = WiKicker::DikiCGI::Environment->new(configuration => $configuration);
  my $manager = WiKicker::Diki::DataManager
    ->new(directory => 't/tmp/DikiDataManagerTest', environment => $env);

  my $diary_day_list = $manager->get_recent_diaries(5);
  is($diary_day_list->size, 0);
}

#=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
#    empty
#-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
# create month dir
{
  mkpath(['t/tmp/DikiDataManagerTest/primary/2004/06']);

  my $configuration = WiKicker::DikiCGI::Configuration->new;
  my $env = WiKicker::DikiCGI::Environment->new(configuration => $configuration);
  my $manager = WiKicker::Diki::DataManager
    ->new(directory => 't/tmp/DikiDataManagerTest', environment => $env);

  my $diary_day_list = $manager->get_recent_diaries(5);
  is($diary_day_list->size, 0);
}

#=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
#    1 article (secondary update)
#-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
my $properties = <<__ENDSTR__;
dikicker.database.directory: t/tmp/DikiDataManagerTest
__ENDSTR__

open(PROPERTIES, '>t/tmp/DikiDataManagerTest/properties.txt')
  || die $!;
print PROPERTIES $properties;
close(PROPERTIES);

{
  my $article = <<__ENDSTR__;
* test
test
__ENDSTR__

  open(ARTICLE, '>t/tmp/DikiDataManagerTest/primary/2004/06/2004-06-10-test.dkd') || die $!;
  print ARTICLE $article;
  close(ARTICLE);

  $ENV{SCRIPT_NAME} = '/diki';

  my $configuration = WiKicker::DikiCGI::Configuration->new(properties_file => 't/tmp/DikiDataManagerTest/properties.txt');
  my $env = WiKicker::DikiCGI::Environment->new(configuration => $configuration);
  my $manager = WiKicker::Diki::DataManager
    ->new(directory => 't/tmp/DikiDataManagerTest', environment => $env);

  Log::Log4perl->get_logger->debug('New article 2004-06-10-test ----------------------------------------------');

  my $diary_day_list = $manager->get_recent_diaries(5);
  is($diary_day_list->size, 1);
}

#=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
#    1 article (touch)
#-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
{
  sleep(1);

  my $article = <<__ENDSTR__;
* test
test
__ENDSTR__

  open(ARTICLE, '>t/tmp/DikiDataManagerTest/primary/2004/06/2004-06-10-test.dkd') || die $!;
  print ARTICLE $article;
  close(ARTICLE);

  $ENV{SCRIPT_NAME} = '/diki';

  my $configuration = WiKicker::DikiCGI::Configuration->new(properties_file => 't/tmp/DikiDataManagerTest/properties.txt');
  my $env = WiKicker::DikiCGI::Environment->new(configuration => $configuration);
  my $manager = WiKicker::Diki::DataManager
    ->new(directory => 't/tmp/DikiDataManagerTest', environment => $env);

  Log::Log4perl->get_logger->debug('Update article 2004-06-10-test (touch only) ---------------------------');

  my $diary_day_list = $manager->get_recent_diaries(5);
  is($diary_day_list->size, 1);
}

#=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
#    remove article (secondary update)
#-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
# no file
{
  unlink('t/tmp/DikiDataManagerTest/primary/2004/06/2004-06-10-test.dkd');

  $ENV{SCRIPT_NAME} = '/diki';

  my $configuration = WiKicker::DikiCGI::Configuration
    ->new(properties_file => 't/tmp/DikiDataManagerTest/properties.txt');
  my $env = WiKicker::DikiCGI::Environment->new(configuration => $configuration);
  my $manager = WiKicker::Diki::DataManager
    ->new(directory => 't/tmp/DikiDataManagerTest', environment => $env);

  Log::Log4perl->get_logger->debug('Remove article 2004-06-10-test ---------------------------');

  my $diary_day_list = $manager->secondary->get_recent_diaries(5);
  is($diary_day_list->size, 1);

  $diary_day_list = $manager->get_recent_diaries(5);
  is($diary_day_list->size, 0);
}

#=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
#    1 article (with explicit keyword)
#-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
{
  my $article = <<__ENDSTR__;
* [[test]]
test
__ENDSTR__

  open(ARTICLE, '>t/tmp/DikiDataManagerTest/primary/2004/06/2004-06-11-test.dkd') || die $!;
  print ARTICLE $article;
  close(ARTICLE);

  $ENV{SCRIPT_NAME} = '/diki';

  my $configuration = WiKicker::DikiCGI::Configuration->new(properties_file => 't/tmp/DikiDataManagerTest/properties.txt');
  my $env = WiKicker::DikiCGI::Environment->new(configuration => $configuration);
  my $manager = WiKicker::Diki::DataManager
    ->new(directory => 't/tmp/DikiDataManagerTest', environment => $env);

  Log::Log4perl->get_logger->debug('Add article 2004-06-11-test (and [[test]])---------------------------');

  my $diary_day_list = $manager->get_recent_diaries(5);
  is($diary_day_list->size, 1);
}

#=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
#    remove article (have explicit keyword)
#-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
# none
{
  unlink('t/tmp/DikiDataManagerTest/primary/2004/06/2004-06-11-test.dkd');

  $ENV{SCRIPT_NAME} = '/diki';

  my $configuration = WiKicker::DikiCGI::Configuration
    ->new(properties_file => 't/tmp/DikiDataManagerTest/properties.txt');
  my $env = WiKicker::DikiCGI::Environment->new(configuration => $configuration);
  my $manager = WiKicker::Diki::DataManager
    ->new(directory => 't/tmp/DikiDataManagerTest', environment => $env);

  Log::Log4perl->get_logger->debug('Remove article 2004-06-11-test (and [[test]]) ---------------------------');

  my $diary_day_list = $manager->get_recent_diaries(5);
  is($diary_day_list->size, 0);
}

#=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
#    (setup test)
#-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
{
  my $article = <<__ENDSTR__;
* [[test]]
test
__ENDSTR__

  sleep(2);

  open(ARTICLE, '>t/tmp/DikiDataManagerTest/primary/2004/06/2004-06-11-test.dkd') || die $!;
  print ARTICLE $article;
  close(ARTICLE);

  $ENV{SCRIPT_NAME} = '/diki';

  my $configuration = WiKicker::DikiCGI::Configuration->new(properties_file => 't/tmp/DikiDataManagerTest/properties.txt');
  my $env = WiKicker::DikiCGI::Environment->new(configuration => $configuration);
  my $manager = WiKicker::Diki::DataManager
    ->new(directory => 't/tmp/DikiDataManagerTest', environment => $env);

  Log::Log4perl->get_logger->debug('Add article 2004-06-11-test again (and [[test]])---------------------------');

  my $diary_day_list = $manager->get_recent_diaries(5);
  is($diary_day_list->size, 1);
}

#=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
#    (add explicit term)
#-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
{
  my $article = <<__ENDSTR__;
* [[test]]
test
[[test3]]
__ENDSTR__

  sleep(2);

  open(ARTICLE, '>t/tmp/DikiDataManagerTest/primary/2004/06/2004-06-11-test.dkd') || die $!;
  print ARTICLE $article;
  close(ARTICLE);

  $ENV{SCRIPT_NAME} = '/diki';

  my $configuration = WiKicker::DikiCGI::Configuration->new(properties_file => 't/tmp/DikiDataManagerTest/properties.txt');
  my $env = WiKicker::DikiCGI::Environment->new(configuration => $configuration);
  my $manager = WiKicker::Diki::DataManager
    ->new(directory => 't/tmp/DikiDataManagerTest', environment => $env);

  Log::Log4perl->get_logger->debug('Add [[test3]]) ---------------------------');

  my $diary_day_list = $manager->get_recent_diaries(5);
  is($diary_day_list->size, 1);
}

#=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
#    (remove explicit term)
#-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
{
  my $article = <<__ENDSTR__;
* test
test
[[test3]]
__ENDSTR__

  sleep(2);

  open(ARTICLE, '>t/tmp/DikiDataManagerTest/primary/2004/06/2004-06-11-test.dkd') || die $!;
  print ARTICLE $article;
  close(ARTICLE);

  $ENV{SCRIPT_NAME} = '/diki';

  my $configuration = WiKicker::DikiCGI::Configuration->new(properties_file => 't/tmp/DikiDataManagerTest/properties.txt');
  my $env = WiKicker::DikiCGI::Environment->new(configuration => $configuration);
  my $manager = WiKicker::Diki::DataManager
    ->new(directory => 't/tmp/DikiDataManagerTest', environment => $env);

  Log::Log4perl->get_logger->debug('Remove [[test]] ---------------------------');

  my $diary_day_list = $manager->get_recent_diaries(5);
  is($diary_day_list->size, 1);
}

{
  sleep(2);

  $ENV{SCRIPT_NAME} = '/diki';

  my $configuration = WiKicker::DikiCGI::Configuration->new(properties_file => 't/tmp/DikiDataManagerTest/properties.txt');
  my $env = WiKicker::DikiCGI::Environment->new(configuration => $configuration);
  my $manager = WiKicker::Diki::DataManager
    ->new(directory => 't/tmp/DikiDataManagerTest', environment => $env);

  Log::Log4perl->get_logger->debug('Reread ---------------------------');

  my $diary_day_list = $manager->get_recent_diaries(5);
  is($diary_day_list->size, 1);
}

#=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
#    (setup)
#-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
{
  my $article = <<__ENDSTR__;
* test3
test4
test5
test6
test7
test8
[[aaa]]
__ENDSTR__

  sleep(2);

  open(ARTICLE, '>t/tmp/DikiDataManagerTest/primary/2004/06/2004-06-12-test.dkd') || die $!;
  print ARTICLE $article;
  close(ARTICLE);

  $ENV{SCRIPT_NAME} = '/diki';

  my $configuration = WiKicker::DikiCGI::Configuration->new(properties_file => 't/tmp/DikiDataManagerTest/properties.txt');
  my $env = WiKicker::DikiCGI::Environment->new(configuration => $configuration);
  my $manager = WiKicker::Diki::DataManager
    ->new(directory => 't/tmp/DikiDataManagerTest', environment => $env);

  my $diary_day_list = $manager->get_recent_diaries(5);
  is($diary_day_list->size, 2);
}

#=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
#    (remove article, remove explicit)
#-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
{
  unlink('t/tmp/DikiDataManagerTest/primary/2004/06/2004-06-11-test.dkd');

  $ENV{SCRIPT_NAME} = '/diki';

  my $configuration = WiKicker::DikiCGI::Configuration->new(properties_file => 't/tmp/DikiDataManagerTest/properties.txt');
  my $env = WiKicker::DikiCGI::Environment->new(configuration => $configuration);
  my $manager = WiKicker::Diki::DataManager
    ->new(directory => 't/tmp/DikiDataManagerTest', environment => $env);

  my $diary_day_list = $manager->get_recent_diaries(5);
  is($diary_day_list->size, 1);
}

#=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
#    (remove implicit)
#-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
{
  my $configuration = WiKicker::DikiCGI::Configuration->new(properties_file => 't/tmp/DikiDataManagerTest/properties.txt');
  my $env = WiKicker::DikiCGI::Environment->new(configuration => $configuration);
  my $manager = WiKicker::Diki::DataManager
    ->new(directory => 't/tmp/DikiDataManagerTest', environment => $env);

  my $diary_day_list = $manager->get_recent_diaries(5);
  is($diary_day_list->size, 1);
}

{
  my $configuration = WiKicker::DikiCGI::Configuration->new(properties_file => 't/tmp/DikiDataManagerTest/properties.txt');
  my $env = WiKicker::DikiCGI::Environment->new(configuration => $configuration);
  my $manager = WiKicker::Diki::DataManager
    ->new(directory => 't/tmp/DikiDataManagerTest', environment => $env);

  my $diary_day_list = $manager->get_recent_diaries(5);
  is($diary_day_list->size, 1);
}

#=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
#    New keyword
#-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
{
  my $article = <<__ENDSTR__;
* [[test4]]
aaa
__ENDSTR__

  sleep(2);

  mkpath(['t/tmp/DikiDataManagerTest/primary/keyword']);

  open(ARTICLE, '>t/tmp/DikiDataManagerTest/primary/keyword/test4.dkk') || die $!;
  print ARTICLE $article;
  close(ARTICLE);

  $ENV{SCRIPT_NAME} = '/diki';

  my $configuration = WiKicker::DikiCGI::Configuration->new(properties_file => 't/tmp/DikiDataManagerTest/properties.txt');
  my $env = WiKicker::DikiCGI::Environment->new(configuration => $configuration);
  my $manager = WiKicker::Diki::DataManager
    ->new(directory => 't/tmp/DikiDataManagerTest', environment => $env);

  $manager->check_keyword_files_update;

  my $diary_day_list = $manager->get_recent_diaries(5);
  is($diary_day_list->size, 1);

  my $keyword_list = $manager->get_keywords('test4');
  is($keyword_list->size, 1);
}

# 2004-06-11-test term list update.
{
  my $configuration = WiKicker::DikiCGI::Configuration->new(properties_file => 't/tmp/DikiDataManagerTest/properties.txt');
  my $env = WiKicker::DikiCGI::Environment->new(configuration => $configuration);
  my $manager = WiKicker::Diki::DataManager
    ->new(directory => 't/tmp/DikiDataManagerTest', environment => $env);

  my $diary_day_list = $manager->get_recent_diaries(5);
  is($diary_day_list->size, 1);
}

# 2004-06-11-test term list update.
{
  my $configuration = WiKicker::DikiCGI::Configuration->new(properties_file => 't/tmp/DikiDataManagerTest/properties.txt');
  my $env = WiKicker::DikiCGI::Environment->new(configuration => $configuration);
  my $manager = WiKicker::Diki::DataManager
    ->new(directory => 't/tmp/DikiDataManagerTest', environment => $env);

  my $diary_day_list = $manager->get_recent_diaries(5);
  is($diary_day_list->size, 1);
}

#=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
#    Change keyword
#-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
{
  my $article = <<__ENDSTR__;
* [[test4]]
test3
[[test5]]
test5
__ENDSTR__

  sleep(2);

  open(ARTICLE, '>t/tmp/DikiDataManagerTest/primary/keyword/test4.dkk') || die $!;
  print ARTICLE $article;
  close(ARTICLE);

  $ENV{SCRIPT_NAME} = '/diki';

  my $configuration = WiKicker::DikiCGI::Configuration->new(properties_file => 't/tmp/DikiDataManagerTest/properties.txt');
  my $env = WiKicker::DikiCGI::Environment->new(configuration => $configuration);
  my $manager = WiKicker::Diki::DataManager
    ->new(directory => 't/tmp/DikiDataManagerTest', environment => $env);

  $manager->check_keyword_files_update;

  my $diary_day_list = $manager->get_recent_diaries(5);
  is($diary_day_list->size, 1);

  my $keyword_list = $manager->get_keywords('test4');
  is($keyword_list->size, 1);
}

# 2004-06-12-test term list update.
{
  my $configuration = WiKicker::DikiCGI::Configuration->new(properties_file => 't/tmp/DikiDataManagerTest/properties.txt');
  my $env = WiKicker::DikiCGI::Environment->new(configuration => $configuration);
  my $manager = WiKicker::Diki::DataManager
    ->new(directory => 't/tmp/DikiDataManagerTest', environment => $env);

  my $diary_day_list = $manager->get_recent_diaries(5);
  is($diary_day_list->size, 1);
}

#=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
#    Change keyword
#-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
{
  my $article = <<__ENDSTR__;
* [[test4]]
test3
test5
__ENDSTR__

  sleep(2);

  open(ARTICLE, '>t/tmp/DikiDataManagerTest/primary/keyword/test4.dkk') || die $!;
  print ARTICLE $article;
  close(ARTICLE);

  $ENV{SCRIPT_NAME} = '/diki';

  my $configuration = WiKicker::DikiCGI::Configuration->new(properties_file => 't/tmp/DikiDataManagerTest/properties.txt');
  my $env = WiKicker::DikiCGI::Environment->new(configuration => $configuration);
  my $manager = WiKicker::Diki::DataManager
    ->new(directory => 't/tmp/DikiDataManagerTest', environment => $env);

  $manager->check_keyword_files_update;

  my $diary_day_list = $manager->get_recent_diaries(5);
  is($diary_day_list->size, 1);
}

# 2004-06-12-test term list update.
{
  my $configuration = WiKicker::DikiCGI::Configuration->new(properties_file => 't/tmp/DikiDataManagerTest/properties.txt');
  my $env = WiKicker::DikiCGI::Environment->new(configuration => $configuration);
  my $manager = WiKicker::Diki::DataManager
    ->new(directory => 't/tmp/DikiDataManagerTest', environment => $env);

  my $diary_day_list = $manager->get_recent_diaries(5);
  is($diary_day_list->size, 1);
}

#=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
#    Add def Change keyword
#-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
{
  my $article = <<__ENDSTR__;
-def: test7
* [[test4]]
test3
test5
__ENDSTR__

  sleep(2);

  open(ARTICLE, '>t/tmp/DikiDataManagerTest/primary/keyword/test4.dkk') || die $!;
  print ARTICLE $article;
  close(ARTICLE);

  $ENV{SCRIPT_NAME} = '/diki';

  my $configuration = WiKicker::DikiCGI::Configuration->new(properties_file => 't/tmp/DikiDataManagerTest/properties.txt');
  my $env = WiKicker::DikiCGI::Environment->new(configuration => $configuration);
  my $manager = WiKicker::Diki::DataManager
    ->new(directory => 't/tmp/DikiDataManagerTest', environment => $env);

  $manager->check_keyword_files_update;

  my $diary_day_list = $manager->get_recent_diaries(5);
  is($diary_day_list->size, 1);

  my $keyword_list = $manager->get_keywords('test4');
  is($keyword_list->size, 0);

  $keyword_list = $manager->get_keywords('test7');
  is($keyword_list->size, 1);
}

# 2004-06-12-test term list update.
{
  my $configuration = WiKicker::DikiCGI::Configuration->new(properties_file => 't/tmp/DikiDataManagerTest/properties.txt');
  my $env = WiKicker::DikiCGI::Environment->new(configuration => $configuration);
  my $manager = WiKicker::Diki::DataManager
    ->new(directory => 't/tmp/DikiDataManagerTest', environment => $env);

  my $diary_day_list = $manager->get_recent_diaries(5);
  is($diary_day_list->size, 1);
}

#=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
#    Add def Change keyword
#-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
{
  my $article = <<__ENDSTR__;
-def: test7
-def: test8
* [[test4]]
test3
test5
__ENDSTR__

  sleep(2);

  open(ARTICLE, '>t/tmp/DikiDataManagerTest/primary/keyword/test4.dkk') || die $!;
  print ARTICLE $article;
  close(ARTICLE);

  $ENV{SCRIPT_NAME} = '/diki';

  my $configuration = WiKicker::DikiCGI::Configuration->new(properties_file => 't/tmp/DikiDataManagerTest/properties.txt');
  my $env = WiKicker::DikiCGI::Environment->new(configuration => $configuration);
  my $manager = WiKicker::Diki::DataManager
    ->new(directory => 't/tmp/DikiDataManagerTest', environment => $env);

  $manager->check_keyword_files_update;

  my $diary_day_list = $manager->get_recent_diaries(5);
  is($diary_day_list->size, 1);

  my $keyword_list = $manager->get_keywords('test4');
  is($keyword_list->size, 0);

  $keyword_list = $manager->get_keywords('test7');
  is($keyword_list->size, 1);

  $keyword_list = $manager->get_keywords('test8');
  is($keyword_list->size, 1);
}

# 2004-06-12-test term list update.
{
  my $configuration = WiKicker::DikiCGI::Configuration->new(properties_file => 't/tmp/DikiDataManagerTest/properties.txt');
  my $env = WiKicker::DikiCGI::Environment->new(configuration => $configuration);
  my $manager = WiKicker::Diki::DataManager
    ->new(directory => 't/tmp/DikiDataManagerTest', environment => $env);

  my $diary_day_list = $manager->get_recent_diaries(5);
  is($diary_day_list->size, 1);
}

#=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
#    Add def Change keyword
#-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
{
  my $article = <<__ENDSTR__;
-def: test8
* [[test4]]
test3
test5
__ENDSTR__

  sleep(2);

  open(ARTICLE, '>t/tmp/DikiDataManagerTest/primary/keyword/test4.dkk') || die $!;
  print ARTICLE $article;
  close(ARTICLE);

  $ENV{SCRIPT_NAME} = '/diki';

  my $configuration = WiKicker::DikiCGI::Configuration->new(properties_file => 't/tmp/DikiDataManagerTest/properties.txt');
  my $env = WiKicker::DikiCGI::Environment->new(configuration => $configuration);
  my $manager = WiKicker::Diki::DataManager
    ->new(directory => 't/tmp/DikiDataManagerTest', environment => $env);

  $manager->check_keyword_files_update;

  my $diary_day_list = $manager->get_recent_diaries(5);
  is($diary_day_list->size, 1);

  my $keyword_list = $manager->get_keywords('test4');
  is($keyword_list->size, 0);

  $keyword_list = $manager->get_keywords('test7');
  is($keyword_list->size, 0);

  $keyword_list = $manager->get_keywords('test8');
  is($keyword_list->size, 1);

}

# 2004-06-12-test term list update.
{
  my $configuration = WiKicker::DikiCGI::Configuration->new(properties_file => 't/tmp/DikiDataManagerTest/properties.txt');
  my $env = WiKicker::DikiCGI::Environment->new(configuration => $configuration);
  my $manager = WiKicker::Diki::DataManager
    ->new(directory => 't/tmp/DikiDataManagerTest', environment => $env);

  my $diary_day_list = $manager->get_recent_diaries(5);
  is($diary_day_list->size, 1);
}

#=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
#    Remove keyword
#-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
{
  sleep(2);

  unlink('t/tmp/DikiDataManagerTest/primary/keyword/test4.dkk');

  $ENV{SCRIPT_NAME} = '/diki';

  my $configuration = WiKicker::DikiCGI::Configuration->new(properties_file => 't/tmp/DikiDataManagerTest/properties.txt');
  my $env = WiKicker::DikiCGI::Environment->new(configuration => $configuration);
  my $manager = WiKicker::Diki::DataManager
    ->new(directory => 't/tmp/DikiDataManagerTest', environment => $env);

  $manager->check_keyword_files_update;

  my $diary_day_list = $manager->get_recent_diaries(5);
  is($diary_day_list->size, 1);

  my $keyword_list = $manager->get_keywords('test4');
  is($keyword_list->size, 0);

  $keyword_list = $manager->get_keywords('test7');
  is($keyword_list->size, 0);

  $keyword_list = $manager->get_keywords('test8');
  is($keyword_list->size, 0);
}

{
  my $configuration = WiKicker::DikiCGI::Configuration->new(properties_file => 't/tmp/DikiDataManagerTest/properties.txt');
  my $env = WiKicker::DikiCGI::Environment->new(configuration => $configuration);
  my $manager = WiKicker::Diki::DataManager
    ->new(directory => 't/tmp/DikiDataManagerTest', environment => $env);

  my $diary_day_list = $manager->get_recent_diaries(5);
  is($diary_day_list->size, 1);

  $diary_day_list = $manager->get_recent_keyword_diaries('aaa', 5);
  is($diary_day_list->size, 1);

  $diary_day_list = $manager->get_recent_keyword_diaries('bbb', 5);
  is($diary_day_list->size, 0);
}
