#
# WiKicker
#
#  DocumentParser.t
#
#
# Copyright (C) 2003,2005 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: DocumentParser.t,v 1.6 2005/04/15 13:21:02 naney Exp $
#
#

use strict;
use Test::More tests => 141;

use WiKicker::WikiPage::DocumentParser;
use WiKicker::WRI::Factory;

my $factory = WiKicker::WRI::Factory->new;

# empty
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $document_node = $parser->parse('');
  is($document_node->size, 0);
  is($document_node->to_string, '');
}

# only one paragraph
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $document_node = $parser->parse('a');
  is($document_node->size, 1);
  is($document_node->to_string, 'a');
}

# only one japanese paragraph
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $document_node = $parser->parse('あいうえおかきくけこさしすせそたちつてとなにぬねの');
  is($document_node->size, 1);
  is($document_node->to_string, 'あいうえおかきくけこさしすせそたちつてとなにぬねの');
  my @nodes = $document_node->nodes;
  is(ref $nodes[0], 'WiKicker::WikiPage::ParagraphNode');
}


# two paragraph
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $document_node = $parser->parse("one\n\ntwo");
  is($document_node->size, 3);
  my @nodes = $document_node->nodes;
  is($nodes[0]->to_string, "one\n");
  is($nodes[1]->to_string, "\n");
  is($nodes[2]->to_string, "two");
}

# paragraph, tow empty line, paragraph
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $document_node = $parser->parse("one\n\n\ntwo");
  is($document_node->size, 3);
  my @nodes = $document_node->nodes;
  is($nodes[0]->to_string, "one\n");
  is($nodes[1]->to_string, "\n\n");
  is($nodes[2]->to_string, "two");
}


# h1
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $document_node = $parser->parse("*h1\np\np");
  is($document_node->size, 2);
  my @nodes = $document_node->nodes;
  is($nodes[0]->to_string, "*h1\n");
  is($nodes[0]->level, 1);
  is($nodes[1]->to_string, "p\np");
}

# h2
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $document_node = $parser->parse("*h1\np1\n**h2\np2\n");
  is($document_node->size, 4);
  my @nodes = $document_node->nodes;
  is($nodes[0]->to_string, "*h1\n");
  is($nodes[1]->to_string, "p1\n");
  is($nodes[2]->to_string, "**h2\n");
  is($nodes[3]->to_string, "p2\n");
}

# list
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $document_node = $parser->parse("p1\n-kkk\np2");
  is($document_node->size, 3);
  my @nodes = $document_node->nodes;
  is($nodes[0]->to_string, "p1\n");
  is($nodes[1]->to_string, "-kkk\n");
  is($nodes[2]->to_string, "p2");
}

# list
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $document_node = $parser->parse("p1\n#kkk\np2");
  is($document_node->size, 3);
  my @nodes = $document_node->nodes;
  is($nodes[0]->to_string, "p1\n");
  is($nodes[1]->to_string, "#kkk\n");
  is($nodes[2]->to_string, "p2");
}


# list
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
my $text = <<EOS;
p1
--kkk
p2
EOS
  my $document_node = $parser->parse($text);
  is($document_node->size, 3);
  my @nodes = $document_node->nodes;
  is($nodes[0]->to_string, "p1\n");
  is($nodes[1]->to_string, "--kkk\n");
  is($nodes[2]->to_string, "p2\n");
}

# list
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
my $text = <<EOS;
p1
##kkk
p2
EOS
  my $document_node = $parser->parse($text);
  is($document_node->size, 3);
  my @nodes = $document_node->nodes;
  is($nodes[0]->to_string, "p1\n");
  is($nodes[1]->to_string, "##kkk\n");
  is($nodes[2]->to_string, "p2\n");
}

# list
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
my $text = <<EOS;
p1
---kkk
p2
EOS
  my $document_node = $parser->parse($text);
  is($document_node->size, 3);
  my @nodes = $document_node->nodes;
  is($nodes[0]->to_string, "p1\n");
  is($nodes[1]->to_string, "---kkk\n");
  is($nodes[2]->to_string, "p2\n");
}

# list
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
my $text = <<EOS;
p1
###kkk
p2
EOS
  my $document_node = $parser->parse($text);
  is($document_node->size, 3);
  my @nodes = $document_node->nodes;
  is($nodes[0]->to_string, "p1\n");
  is($nodes[1]->to_string, "###kkk\n");
  is($nodes[2]->to_string, "p2\n");
}

# list
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
my $text = <<EOS;
p1
-a
--b
p2
EOS
  my $document_node = $parser->parse($text);
  is($document_node->size, 3);
  my @nodes = $document_node->nodes;
  is($nodes[0]->to_string, "p1\n");
  is($nodes[1]->to_string, "-a\n--b\n");
  is($nodes[2]->to_string, "p2\n");
}

# list
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
my $text = <<EOS;
p1
#a
##b
p2
EOS
  my $document_node = $parser->parse($text);
  is($document_node->size, 3);
  my @nodes = $document_node->nodes;
  is($nodes[0]->to_string, "p1\n");
  is($nodes[1]->to_string, "#a\n##b\n");
  is($nodes[2]->to_string, "p2\n");
}


# list
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $text = '--- book';
  my $document_node = $parser->parse($text);
  is($document_node->to_string, '--- book');
}

# hr
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
my $text = <<EOS;
p1
----
p2
EOS
  my $document_node = $parser->parse($text);
  is($document_node->size, 3);
  my @nodes = $document_node->nodes;
  is($nodes[0]->to_string, "p1\n");
  is($nodes[1]->to_string, "----\n");
  is($nodes[2]->to_string, "p2\n");
}


# paragraph, pre, paragraph
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $document_node = $parser->parse("p1\n k\n k\n k\np2");
  is($document_node->size, 3);
  my @nodes = $document_node->nodes;
  is($nodes[0]->to_string, "p1\n");
  is($nodes[1]->to_string, " k\n k\n k\n");
  is($nodes[2]->to_string, "p2");
}

# paragraph,pre,empty,paragraph
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $document_node = $parser->parse("p1\n k\n\np2");
  is($document_node->size, 4);
  my @nodes = $document_node->nodes;
  is($nodes[0]->to_string, "p1\n");
  is($nodes[1]->to_string, " k\n");
  is($nodes[2]->to_string, "\n");
  is($nodes[3]->to_string, "p2");
}

# paragraph,pre,empty,pre,paragraph
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $document_node = $parser->parse("p1\n pre1\n\n\n pre2\np2");
  is($document_node->size, 3);
  my @nodes = $document_node->nodes;
  is($nodes[0]->to_string, "p1\n");
  is($nodes[1]->to_string, " pre1\n\n\n pre2\n");
  is($nodes[2]->to_string, "p2");
}

# paragraph,empty,pre,empty,pre,empty,paragraph
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $document_node = $parser->parse("p1\n\n pre1\n\n\n pre2\n\np2");
  is($document_node->size, 5);
  my @nodes = $document_node->nodes;
  is($nodes[0]->to_string, "p1\n");
  is($nodes[1]->to_string, "\n");
  is($nodes[2]->to_string, " pre1\n\n\n pre2\n");
  is($nodes[3]->to_string, "\n");
  is($nodes[4]->to_string, "p2");
}

# pre,empty
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $document_node = $parser->parse(" pre1\n\n");
  is($document_node->size, 2);
  my @nodes = $document_node->nodes;
  is($nodes[0]->to_string, " pre1\n");
  is($nodes[1]->to_string, "\n");
}

# empty,pre
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $document_node = $parser->parse("\n pre1");
  is($document_node->size, 2);
  my @nodes = $document_node->nodes;
  is($nodes[0]->to_string, "\n");
  is($nodes[1]->to_string, " pre1");
}

# quote
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $document_node = $parser->parse("p1\n> k\n> k\n> k\np2");
  is($document_node->size, 3);
  my @nodes = $document_node->nodes;
  is($nodes[0]->to_string, "p1\n");
  is($nodes[1]->to_string, "> k\n> k\n> k\n");
  is($nodes[2]->to_string, "p2");
}

# dl
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $document_node = $parser->parse(<<EOS);
p1
:dt:dd
p2
EOS
  is($document_node->size, 3);
  my @nodes = $document_node->nodes;
  is($nodes[0]->to_string, "p1\n");
  is($nodes[1]->to_string, ":dt:dd\n");
  is($nodes[2]->to_string, "p2\n");
}

# _trim
{
  my ($left, $body, $right) = WiKicker::WikiPage::DocumentParser::_trim('a');
  is($left, '');
  is($body, 'a');
  is($right, '');

  ($left, $body, $right) = WiKicker::WikiPage::DocumentParser::_trim(" abc");
  is($left, ' ');
  is($body, 'abc');
  is($right, '');

  ($left, $body, $right) = WiKicker::WikiPage::DocumentParser::_trim("abc ");
  is($left, '');
  is($body, 'abc');
  is($right, ' ');

  ($left, $body, $right) = WiKicker::WikiPage::DocumentParser::_trim(" abc ");
  is($left, ' ');
  is($body, 'abc');
  is($right, ' ');
}

# table |
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $document_node = $parser->parse("a\n|dog\n|cat\nb");
  is($document_node->size, 3);
  my @nodes = $document_node->nodes;
  is($nodes[0]->to_string, "a\n");
  is($nodes[1]->to_string, "|dog\n|cat\n");
  is($nodes[2]->to_string, "b");
}

# table ,
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $document_node = $parser->parse("a\n,dog\n,cat\nb");
  is($document_node->size, 3);
  my @nodes = $document_node->nodes;
  is($nodes[0]->to_string, "a\n");
  is($nodes[1]->to_string, ",dog\n,cat\n");
  is($nodes[2]->to_string, "b");
}

# table , (column with space)
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $document_node = $parser->parse("a\n,dog cat\nb");
  is($document_node->size, 3);
  my @nodes = $document_node->nodes;
  is($nodes[0]->to_string, "a\n");
  is($nodes[1]->to_string, ",dog cat\n");
  is($nodes[2]->to_string, "b");
}

# table , (left space)
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $document_node = $parser->parse("a\n, dog\nb");
  is($document_node->size, 3);
  my @nodes = $document_node->nodes;
  is($nodes[0]->to_string, "a\n");
  is($nodes[1]->to_string, ", dog\n");
  is($nodes[2]->to_string, "b");
}

# table , (right space)
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $document_node = $parser->parse("a\n,dog \nb");
  is($document_node->size, 3);
  my @nodes = $document_node->nodes;
  is($nodes[0]->to_string, "a\n");
  is($nodes[1]->to_string, ",dog \n");
  is($nodes[2]->to_string, "b");
}

# table , (left and right space)
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $document_node = $parser->parse("a\n, dog \nb");
  is($document_node->size, 3);
  my @nodes = $document_node->nodes;
  is($nodes[0]->to_string, "a\n");
  is($nodes[1]->to_string, ", dog \n");
  is($nodes[2]->to_string, "b");
}

# table | (empty cell)
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $document_node = $parser->parse("a\n|a||\nb");
  is($document_node->size, 3);
  my @nodes = $document_node->nodes;
  is($nodes[0]->to_string, "a\n");
  is($nodes[1]->to_string, "|a||\n");
  is($nodes[2]->to_string, "b");
}

{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $document_node = $parser->parse("　after a space");
  is($document_node->size, 1);
  my @nodes = $document_node->nodes;
  is($nodes[0]->to_string, "　after a space");
}


{
  my @result = WiKicker::WikiPage::DocumentParser::_split_to_cell('a', '|');
  ok(eq_array(\@result, [ 'a' ]));

  @result = WiKicker::WikiPage::DocumentParser::_split_to_cell('a|', '|');
  ok(eq_array(\@result, [ 'a', '' ]));

  @result = WiKicker::WikiPage::DocumentParser::_split_to_cell('a||', '|');
  ok(eq_array(\@result, [ 'a', '', '' ]));

  @result = WiKicker::WikiPage::DocumentParser::_split_to_cell('a|b|c', '|');
  ok(eq_array(\@result, [ 'a', 'b', 'c' ]));

  @result = WiKicker::WikiPage::DocumentParser::_split_to_cell('', '|');
  ok(eq_array(\@result, [ '' ]));
}
