#
# WiKicker
#
#  GSRVisitor.t
#
#
# Copyright (C) 2003 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: GSRVisitor.t,v 1.3 2003/10/26 23:07:34 naney Exp $
#
#
use strict;
use Test;

BEGIN { plan tests => 13 }

use WiKicker::WikiPage::DocumentParser;
use WiKicker::WikiPage::GetSectionRawVisitor;
use WiKicker::WRI::Factory;

my $factory = WiKicker::WRI::Factory->new;

# emptry
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $visitor = WiKicker::WikiPage::GetSectionRawVisitor->new;
  my $document_node = $parser->parse('');

  $visitor->section_number(-1);
  $visitor->visit($document_node);

  ok($visitor->section eq '');
}

# emptry
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $visitor = WiKicker::WikiPage::GetSectionRawVisitor->new;
  my $document_node = $parser->parse('');

  $visitor->section_number(0);
  $visitor->visit($document_node);

  ok($visitor->section eq '');
}

# emptry
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $visitor = WiKicker::WikiPage::GetSectionRawVisitor->new;
  my $document_node = $parser->parse('');

  $visitor->section_number(1);
  $visitor->visit($document_node);

  ok($visitor->section eq '');
}

my $test_document_1 = <<__ENDSTR__;
abc
*h1
def
*h2
hij
__ENDSTR__
  
# normal
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $visitor = WiKicker::WikiPage::GetSectionRawVisitor->new;
  my $document_node = $parser->parse($test_document_1);

  $visitor->section_number(-1);
  $visitor->visit($document_node);

  ok($visitor->section eq '');
}

# normal
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $visitor = WiKicker::WikiPage::GetSectionRawVisitor->new;
  my $document_node = $parser->parse($test_document_1);

  $visitor->section_number(0);
  $visitor->visit($document_node);

  ok($visitor->section eq "abc\n");
}

# normal
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $visitor = WiKicker::WikiPage::GetSectionRawVisitor->new;
  my $document_node = $parser->parse($test_document_1);

  $visitor->section_number(1);
  $visitor->visit($document_node);

  ok($visitor->section eq "*h1\ndef\n");
}

# normal
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $visitor = WiKicker::WikiPage::GetSectionRawVisitor->new;
  my $document_node = $parser->parse($test_document_1);

  $visitor->section_number(2);
  $visitor->visit($document_node);

  ok($visitor->section eq "*h2\nhij\n");
}

# normal
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $visitor = WiKicker::WikiPage::GetSectionRawVisitor->new;
  my $document_node = $parser->parse($test_document_1);

  $visitor->section_number(3);
  $visitor->visit($document_node);

  ok($visitor->section eq '');
}

my $test_document_2 = <<__ENDSTR__;
abc
*h1
def
**h2
hij
***h3
klm
__ENDSTR__
  
# normal
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $visitor = WiKicker::WikiPage::GetSectionRawVisitor->new;
  my $document_node = $parser->parse($test_document_2);

  $visitor->section_number(-1);
  $visitor->visit($document_node);

  ok($visitor->section eq '');
}

# normal
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $visitor = WiKicker::WikiPage::GetSectionRawVisitor->new;
  my $document_node = $parser->parse($test_document_2);

  $visitor->section_number(0);
  $visitor->visit($document_node);

  ok($visitor->section eq "abc\n");
}

# normal
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $visitor = WiKicker::WikiPage::GetSectionRawVisitor->new;
  my $document_node = $parser->parse($test_document_2);

  $visitor->section_number(1);
  $visitor->visit($document_node);

  ok($visitor->section eq "*h1\ndef\n");
}

# normal
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $visitor = WiKicker::WikiPage::GetSectionRawVisitor->new;
  my $document_node = $parser->parse($test_document_2);

  $visitor->section_number(2);
  $visitor->visit($document_node);

  ok($visitor->section eq "**h2\nhij\n***h3\nklm\n");
}

# normal
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $visitor = WiKicker::WikiPage::GetSectionRawVisitor->new;
  my $document_node = $parser->parse($test_document_2);

  $visitor->section_number(3);
  $visitor->visit($document_node);

  ok($visitor->section eq '');
}
