#
# WiKicker
#
#  GSVisitor.t
#
#
# Copyright (C) 2003 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: GSVisitor.t,v 1.4 2003/10/26 23:07:34 naney Exp $
#
#

use strict;
use Test;

BEGIN { plan tests => 9 }

use WiKicker::WikiPage::DocumentParser;
use WiKicker::WikiPage::GetSubjectVisitor;
use WiKicker::WRI::Factory;

my $factory = WiKicker::WRI::Factory->new;

# emptry
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $visitor = WiKicker::WikiPage::GetSubjectVisitor->new(wri_factory => $factory);
  my $document_node = $parser->parse('');

  $visitor->visit($document_node);

  ok($visitor->subject(20) eq '');
}

# paragraph
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $visitor = WiKicker::WikiPage::GetSubjectVisitor->new(wri_factory => $factory);
  my $document_node = $parser->parse('p');

  $visitor->visit($document_node);

  ok($visitor->subject(20) eq 'p');
}

# paragraph (long)
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $visitor = WiKicker::WikiPage::GetSubjectVisitor->new(wri_factory => $factory);
  my $document_node = $parser->parse('0123456789abcdefghijklmnopqrstuvwxyz');

  $visitor->visit($document_node);

  ok($visitor->subject(20) eq '0123456789abcdefg...');
}

# paragraph (long japanese)
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $visitor = WiKicker::WikiPage::GetSubjectVisitor->new(wri_factory => $factory);
  my $document_node = $parser->parse('あいうえおかきくけこさしすせそたちつてとなにぬねの');

  $visitor->visit($document_node);

  ok($visitor->subject(100) eq 'あいうえおかきくけこさしすせそたちつてとなにぬねの');
  ok($visitor->subject(20) eq 'あいうえおかきくけこさしすせそたち...');
}

# paragraph with ====
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $visitor = WiKicker::WikiPage::GetSubjectVisitor->new(wri_factory => $factory);
  my $document_node = $parser->parse('ab====cd====ef');
  $visitor->visit($document_node);
  ok($visitor->subject(100) eq 'abcdef');
}

# [[page-subject:..]]
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $visitor = WiKicker::WikiPage::GetSubjectVisitor->new(wri_factory => $factory);
  my $document_node = $parser->parse('[[page-subject:abc]]def');
  $visitor->visit($document_node);
  ok($visitor->subject(100) eq 'abcdef');
}

# [[form:long]]
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $visitor = WiKicker::WikiPage::GetSubjectVisitor->new(wri_factory => $factory);
  my $document_node = $parser->parse("[[form:long]]");
  $visitor->visit($document_node);
  ok($visitor->subject(100) eq '');
}

# [[image:ASIN:...]]
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $visitor = WiKicker::WikiPage::GetSubjectVisitor->new(wri_factory => $factory);
  my $document_node = $parser->parse("[[image:ASIN:B000066HMX]]");
  $visitor->visit($document_node);
  ok($visitor->subject(100) eq '');
}
