#
# WiKicker
#
#  HFVisitor.t
#
#
# Copyright (C) 2003,2004,2005 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: HFVisitor.t,v 1.12 2005/04/04 14:09:16 naney Exp $
#
#

use strict;
use Test;

BEGIN { plan tests => 7 }

use WiKicker::WikiPage::WikiPageHtmlFragmentVisitor;
use WiKicker::WikiPage::DocumentParser;
use WiKicker::WikiPage::Env;
use WiKicker::HTML::LinkMaker;
use WiKicker::WRI::Factory;
use CGI (-no_debug);

my $factory = WiKicker::WRI::Factory->new;
my $env = WiKicker::WikiPage::HtmlEnv
  ->new(user => '',
        resolver => '',
        wikicker_url => '/wiki',
        wri_factory => $factory,
        environment => DbMock->new,
        query => '',
        page_name => '',
        localizer => DbMock->new);

$env->link_maker(WiKicker::HTML::LinkMaker->new_from_html_env(env => $env));

# [[]]
{
  my $document_node = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory)->parse('[[]]');

  my $visitor = WiKicker::WikiPage::WikiPageHtmlFragmentVisitor->new;
  $visitor->env($env);
  $visitor->no_edit_section(1);

  $visitor->visit($document_node);

  my $content = $visitor->content;
  ok($visitor->content eq "<p>[[]]</p>\n");
}

# test visit_PreNode
{
  my $document_node = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory)->parse(<<ENDSTR);
ab
 cd
ef
ENDSTR

  my $visitor = WiKicker::WikiPage::WikiPageHtmlFragmentVisitor->new;
  $visitor->env($env);
  $visitor->no_edit_section(1);
  $visitor->visit($document_node);
  my $content = $visitor->content;
  ok($content =~ m|<pre>.*</pre>|s);
}

# test visit_QuoteNode
{
  my $document_node = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory)->parse(<<ENDSTR);
ab
>cd
ef
ENDSTR

  my $visitor = WiKicker::WikiPage::WikiPageHtmlFragmentVisitor->new;
  $visitor->env($env);
  $visitor->no_edit_section(1);

  $visitor->visit($document_node);

  my $content = $visitor->content;
  ok($content =~ m|<blockquote>.*</blockquote>|s);
}

# test visit_QuoteNode
{
  my $document_node = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory)->parse(<<ENDSTR);
ab
:cd:ef
gh
ENDSTR

  my $visitor = WiKicker::WikiPage::WikiPageHtmlFragmentVisitor->new;
  $visitor->env($env);
  $visitor->no_edit_section(1);

  $visitor->visit($document_node);

  my $content = $visitor->content;
  ok($content =~ m|<dl>.*<dt>.*</dt>.*<dd>.*</dd>.*</dl>|s);
}

# [[index:child]]
{
  my $document_node = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory)->parse('[[index:child]]');

  my $visitor = WiKicker::WikiPage::WikiPageHtmlFragmentVisitor->new;
  my $env = WiKicker::WikiPage::HtmlEnv
    ->new(user => '',
          resolver => '',
          wikicker_url => '/wiki',
          wri_factory => $factory,
          environment => DbMock->new,
          query => CGI->new,
          page_name => 'PageName',
          localizer => DbMock->new);
  $env->link_maker(WiKicker::HTML::LinkMaker->new_from_html_env(env => $env));
  $visitor->env($env);
  $visitor->no_edit_section(1);

  $visitor->visit($document_node);

  my $content = $visitor->content;
  ok($content =~ /<ul>/);
}

# [[form:comment]]
{
  my $document_node = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory)->parse('[[form:comment]]');

  my $visitor = WiKicker::WikiPage::WikiPageHtmlFragmentVisitor->new;
  my $env = WiKicker::WikiPage::HtmlEnv
    ->new(user => '',
          resolver => '',
          wikicker_url => '/wiki',
          wri_factory => $factory,
          environment => DbMock->new,
          query => CGI->new,
          page_name => 'PageName',
          localizer => DbMock->new);
  $visitor->env($env);
  $visitor->no_edit_section(1);

  $visitor->visit($document_node);

  my $content = $visitor->content;
  ok($visitor->content =~ /"1234"/);
}

# [[form:long]]
{
  my $document_node = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory)->parse('[[form:long]]');

  my $visitor = WiKicker::WikiPage::WikiPageHtmlFragmentVisitor->new;
  my $env = WiKicker::WikiPage::HtmlEnv
    ->new(user => '',
          resolver => '',
          wikicker_url => '/wiki',
          wri_factory => $factory,
          environment => DbMock->new,
          query => CGI->new,
          page_name => 'PageName',
          localizer => DbMock->new);
  $visitor->env($env);
  $visitor->no_edit_section(1);

  $visitor->visit($document_node);

  my $content = $visitor->content;
  ok($visitor->content =~ /"1234"/);
}

package DbMock;

sub new {
  my $class = shift;

  return bless {}, $class;
}

sub last_modified {
  return 1234;
}

sub page_name_list {
  return shift;
}

sub list {
  return ();
}

sub page_list_with_predicate {
  return qw(a/b a/c);
}

sub page_subject {
  return '(subject)';
}

sub db {
  return shift;
}

sub configuration {
  return shift;
}
