#
# WiKicker
#
#  InlineParser.t
#
#
# Copyright (C) 2003,2004 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: InlineParser.t,v 1.7 2004/08/03 12:48:25 naney Exp $
#
#

use strict;
use Test;

BEGIN { plan tests => 128 }

use CGI;
use WiKicker::WikiPage::InlineParser;
use WiKicker::WRI::Factory;

my $factory = WiKicker::WRI::Factory->new;

# constructor (no wr_factory param)
{
  eval {
    my $parser = WiKicker::WikiPage::InlineParser->new;
  };
  if ($@) {
    ok(1);
  }
  else {
    ok(0);
  }
}


# empty
{
  my $parser = WiKicker::WikiPage::InlineParser->new(wri_factory => $factory);
  my @nodes = $parser->parse('');
  ok(@nodes == 0);
}

{
  my $parser = WiKicker::WikiPage::InlineParser->new(wri_factory => $factory);
  my @nodes = $parser->parse('a');
  ok(@nodes == 1);
  ok($nodes[0]->to_string eq 'a');
}

{
  my $parser = WiKicker::WikiPage::InlineParser->new(wri_factory => $factory);
  my @nodes = $parser->parse("a WikiName");
  ok (@nodes == 2);
  ok($nodes[0]->to_string eq 'a ');
  ok($nodes[1]->to_string eq 'WikiName');
}

{
  my $parser = WiKicker::WikiPage::InlineParser->new(wri_factory => $factory);
  my @nodes = $parser->parse("a ClassName/WikiName b");
  ok (@nodes == 3);
  ok($nodes[0]->to_string eq 'a ');
  ok($nodes[1]->to_string eq 'ClassName/WikiName');
  ok($nodes[2]->to_string eq ' b');
}

{
  my $parser = WiKicker::WikiPage::InlineParser->new(wri_factory => $factory);
  my @nodes = $parser->parse("a WikiName#fragment ");
  ok(@nodes == 3);
  ok($nodes[0]->to_string eq 'a ');
  ok($nodes[1]->to_string eq 'WikiName#fragment');
  ok($nodes[2]->to_string eq ' ');
}

{
  my $parser = WiKicker::WikiPage::InlineParser->new(wri_factory => $factory);
  my @nodes = $parser->parse("a #fragment b");
  ok(@nodes == 1);
  ok($nodes[0]->to_string eq 'a #fragment b');
}

{
  my $parser = WiKicker::WikiPage::InlineParser->new(wri_factory => $factory);
  my @nodes = $parser->parse("a #フラグメント b");
  ok(@nodes == 1);
  ok($nodes[0]->to_string eq "a #フラグメント b");
}

{
  my $parser = WiKicker::WikiPage::InlineParser->new(wri_factory => $factory);
  my @nodes = $parser->parse("a WikiName#フラグメント ");
  ok(@nodes == 3);
  ok($nodes[0]->to_string eq 'a ');
  ok($nodes[1]->to_string eq 'WikiName#フラグメント');
  ok($nodes[2]->to_string eq ' ');
}



{
  my $parser = WiKicker::WikiPage::InlineParser->new(wri_factory => $factory);
  my @nodes = $parser->parse("a WikiNameA");
  ok (@nodes == 1);
  ok($nodes[0]->to_string eq 'a WikiNameA');
}

{
  my $parser = WiKicker::WikiPage::InlineParser->new(wri_factory => $factory);
  my @nodes = $parser->parse("a [[WikiName]] b");
  ok (@nodes == 3);
  ok($nodes[0]->to_string eq 'a ');
  ok($nodes[1]->to_string eq '[[WikiName]]');
  ok($nodes[1]->reference eq 'WikiName');
  ok(!defined $nodes[1]->content);
  ok($nodes[2]->to_string eq ' b');
}

{
  my $parser = WiKicker::WikiPage::InlineParser->new(wri_factory => $factory);
  my @nodes = $parser->parse("a [[[WikiName]] b");
  ok (@nodes == 3);
  ok($nodes[0]->to_string eq 'a ');
  ok($nodes[1]->to_string eq '[[[WikiName]]');
  ok($nodes[1]->reference eq '[WikiName');
  ok(!defined $nodes[1]->content);
  ok($nodes[2]->to_string eq ' b');
}

{
  my $parser = WiKicker::WikiPage::InlineParser->new(wri_factory => $factory);
  my @nodes = $parser->parse("a [[WikiName]]] b");
  ok (@nodes == 3);
  ok($nodes[0]->to_string eq 'a ');
  ok($nodes[1]->to_string eq '[[WikiName]]');
  ok($nodes[1]->reference eq 'WikiName');
  ok(!defined $nodes[1]->content);
  ok($nodes[2]->to_string eq '] b');
}

{
  my $parser = WiKicker::WikiPage::InlineParser->new(wri_factory => $factory);
  my @nodes = $parser->parse("a [[Wiki]Name]] b");
  ok (@nodes == 3);
  ok($nodes[0]->to_string eq 'a ');
  ok($nodes[1]->to_string eq '[[Wiki]Name]]');
  ok($nodes[1]->reference eq 'Wiki]Name');
  ok(!defined $nodes[1]->content);
  ok($nodes[2]->to_string eq ' b');
}

{
  my $parser = WiKicker::WikiPage::InlineParser->new(wri_factory => $factory);
  my @nodes = $parser->parse("a [[Wiki] [Name]] b");
  ok (@nodes == 3);
  ok($nodes[0]->to_string eq 'a ');
  ok($nodes[1]->to_string eq '[[Wiki] [Name]]');
  ok($nodes[1]->reference eq 'Wiki] [Name');
  ok(!defined $nodes[1]->content);
  ok($nodes[2]->to_string eq ' b');
}


{
  my $parser = WiKicker::WikiPage::InlineParser->new(wri_factory => $factory);
  my @nodes = $parser->parse("a [[WikiName][Book]] b");
  ok (@nodes == 3);
  ok($nodes[0]->to_string eq 'a ');
  ok($nodes[1]->to_string eq '[[WikiName][Book]]');
  ok($nodes[1]->reference eq 'WikiName');
  ok($nodes[1]->content eq 'Book');
  ok($nodes[2]->to_string eq ' b');
}

{
  my $parser = WiKicker::WikiPage::InlineParser->new(wri_factory => $factory);
  my @nodes = $parser->parse("a [[Wiki][Name][Book]] b");
  ok (@nodes == 3);
  ok($nodes[0]->to_string eq 'a ');
  ok($nodes[1]->to_string eq '[[Wiki][Name][Book]]');
  ok($nodes[1]->reference eq 'Wiki');
  ok($nodes[1]->content eq 'Name][Book');
  ok($nodes[2]->to_string eq ' b');
}

{
  my $parser = WiKicker::WikiPage::InlineParser->new(wri_factory => $factory);
  my @nodes = $parser->parse("a http://www.naney.org/ b");
  ok(@nodes == 3);
  ok($nodes[0]->to_string eq 'a ');
  ok($nodes[1]->to_string eq 'http://www.naney.org/');
  ok($nodes[2]->to_string eq ' b');
}

{
  my $parser = WiKicker::WikiPage::InlineParser->new(wri_factory => $factory);
  my @nodes = $parser->parse("abc''def''ghi");
  ok(@nodes == 3);
  ok($nodes[0]->to_string eq 'abc');
  ok($nodes[1]->to_string eq "''def''");
  ok($nodes[2]->to_string eq 'ghi');
}

{
  my $parser = WiKicker::WikiPage::InlineParser->new(wri_factory => $factory);
  my @nodes = $parser->parse("abc====def====ghi");
  ok(@nodes == 3);
  ok($nodes[0]->to_string eq 'abc');
  ok($nodes[1]->to_string eq '====def====');
  ok($nodes[2]->to_string eq 'ghi');
  ok($nodes[1]->text eq 'def');
}


# check skipping '0' string (We must not use if ($skip)... )
{
  my $parser = WiKicker::WikiPage::InlineParser->new(wri_factory => $factory);
  my @nodes = $parser->parse("0====def====0");
  ok(@nodes == 3);
  ok($nodes[0]->to_string eq '0');
  ok($nodes[1]->to_string eq '====def====');
  ok($nodes[2]->to_string eq '0');
}

{
  my $parser = WiKicker::WikiPage::InlineParser->new(wri_factory => $factory);
  my @nodes = $parser->parse('a mailto:naney@naney.org b');
  ok(@nodes == 3);
  ok($nodes[0]->to_string eq 'a ');
  ok($nodes[1]->to_string eq 'mailto:naney@naney.org');
  ok($nodes[2]->to_string eq ' b');
}

{
  my $parser = WiKicker::WikiPage::InlineParser->new(wri_factory => $factory);
  my @nodes = $parser->parse("test ISBN0-201-61641-6 test");
  ok(@nodes == 3);
  ok($nodes[0]->to_string eq 'test ');
  ok($nodes[1]->to_string eq 'ISBN0-201-61641-6');
  ok($nodes[2]->to_string eq ' test');
}

{
  my $parser = WiKicker::WikiPage::InlineParser->new(wri_factory => $factory);
  my @nodes = $parser->parse("test ASIN:B000065EA0 test");
  ok(@nodes == 3);
  ok($nodes[0]->to_string eq 'test ');
  ok($nodes[1]->to_string eq 'ASIN:B000065EA0');
  ok($nodes[2]->to_string eq ' test');
}

{
  my $parser = WiKicker::WikiPage::InlineParser->new(wri_factory => $factory);
  my @nodes = $parser->parse("test ASINB000065EA0 test");
  ok(@nodes == 3);
  ok($nodes[0]->to_string eq 'test ');
  ok($nodes[1]->to_string eq 'ASINB000065EA0');
  ok($nodes[2]->to_string eq ' test');
}

{
  my $parser = WiKicker::WikiPage::InlineParser->new(wri_factory => $factory);
  my @nodes = $parser->parse("test rfc1234 test");
  ok(@nodes == 3);
  ok($nodes[0]->to_string eq 'test ');
  ok($nodes[1]->to_string eq 'rfc1234');
  ok($nodes[2]->to_string eq ' test');
}

{
  my $parser = WiKicker::WikiPage::InlineParser->new(wri_factory => $factory);
  my @nodes = $parser->parse("test RFC1234 test");
  ok(@nodes == 3);
  ok($nodes[0]->to_string eq 'test ');
  ok($nodes[1]->to_string eq 'RFC1234');
  ok($nodes[2]->to_string eq ' test');
}

{
  my $parser = WiKicker::WikiPage::InlineParser->new(wri_factory => $factory);
  my @nodes = $parser->parse("test image:ASIN:B000065EA0 test");
  ok(@nodes == 3);
  ok($nodes[0]->to_string eq 'test ');
  ok($nodes[1]->to_string eq 'image:ASIN:B000065EA0');
  ok($nodes[2]->to_string eq ' test');
}

{
  my $parser = WiKicker::WikiPage::InlineParser->new(wri_factory => $factory);
  my @nodes = $parser->parse('http://example/#1234');
  ok(@nodes == 1);
  ok($nodes[0]->to_string eq 'http://example/#1234');
}

{
  my $parser = WiKicker::WikiPage::InlineParser->new(wri_factory => $factory);
  my @nodes = $parser->parse('(http://example/index.html)');
  ok(@nodes == 2);
  ok($nodes[0]->to_string eq '(');
  ok($nodes[1]->to_string eq 'http://example/index.html)');
  # uric include ')'
}

{
  my $parser = WiKicker::WikiPage::InlineParser->new(wri_factory => $factory);
  my @nodes = $parser->parse("http://example/index.html\xe3\x80\x80");
  ok(@nodes == 2);
  ok($nodes[0]->to_string eq 'http://example/index.html');
  ok($nodes[1]->to_string eq "\xe3\x80\x80");
}

{
  my $parser = WiKicker::WikiPage::InlineParser->new(wri_factory => $factory);
  my @nodes = $parser->parse('abc{{fn:def}}ghi');
  ok(@nodes == 3);
  ok($nodes[0]->to_string eq 'abc');
  ok($nodes[1]->to_string eq '{{fn:def}}');
  ok($nodes[2]->to_string, 'ghi');
}

{
  my $parser = WiKicker::WikiPage::InlineParser->new(wri_factory => $factory);
  my @nodes = $parser->parse('abc{{def}}ghi');
  ok(@nodes == 3);
  ok($nodes[0]->to_string eq 'abc');
  ok($nodes[1]->to_string eq '{{def}}');
  ok($nodes[2]->to_string, 'ghi');
}
