#
# WiKicker
#
#  PageNameList.t
#
#
# Copyright (C) 2004 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: PageNameList.t,v 1.3 2004/06/11 14:51:13 naney Exp $
#
#

use strict;
use Test;

BEGIN { plan tests => 38 }

use WiKicker::PageNameList;

# new with no parameter
{
  my $list = WiKicker::PageNameList->new;
  ok(scalar(@{$list->list}), 0);
  ok(!$list->has('a'));
}

# new with parameter
{
  my $list = WiKicker::PageNameList->new([ qw(a b) ]);
  ok(scalar(@{$list->list}), 2);
  ok($list->list->[0], 'a');
  ok($list->list->[1], 'b');

  ok($list->has('a'));
  ok(!$list->has('c'));
}


# full_page_name_list
{
  my @data = qw(A/B/C D/B/C E/F/C F/G/C H/I/J/K C);
  my $list = WiKicker::PageNameList->new(\@data);

  my @result = $list->full_page_name_list('C', \@data);
  ok(@result == 4);
  ok($result[0] eq 'A/B/C');
  ok($result[1] eq 'D/B/C');
  ok($result[2] eq 'E/F/C');
  ok($result[3] eq 'F/G/C');

  # again (use internal cache)
  @result = $list->full_page_name_list('C', \@data);
  ok(@result == 4);
  ok($result[0] eq 'A/B/C');
  ok($result[1] eq 'D/B/C');
  ok($result[2] eq 'E/F/C');
  ok($result[3] eq 'F/G/C');


  @result = $list->full_page_name_list('D', \@data);
  ok(@result == 0);

  @result = $list->full_page_name_list('B/C', \@data);
  ok(@result == 2);
  ok($result[0] eq 'A/B/C');
  ok($result[1] eq 'D/B/C');

  @result = $list->full_page_name_list('A/C', \@data);
  ok(@result == 1);
  ok($result[0] eq 'A/B/C');

  @result = $list->full_page_name_list('F/C', \@data);
  ok(@result == 1);
  ok($result[0] eq 'E/F/C'); # no F/G/C

  @result = $list->full_page_name_list('J/K', \@data);
  ok(@result == 1);
  ok($result[0] eq 'H/I/J/K');

  @result = $list->full_page_name_list('I/K', \@data);
  ok(@result == 1);
  ok($result[0] eq 'H/I/J/K');

  @result = $list->full_page_name_list('H/K', \@data);
  ok(@result == 1);
  ok($result[0] eq 'H/I/J/K');

  @result = $list->full_page_name_list('H/J/K', \@data);
  ok(@result == 1);
  ok($result[0] eq 'H/I/J/K');

  @result = $list->full_page_name_list('H/I/K', \@data);
  ok(@result == 1);
  ok($result[0] eq 'H/I/J/K');

  @result = $list->full_page_name_list('L/C', \@data);
  ok(@result == 0);
}

# full_page_name_list
{
  my @data = qw(A/ABC A/ABCD);
  my $list = WiKicker::PageNameList->new(\@data);

  my @result = $list->full_page_name_list('ABC', \@data);
  ok(@result == 1);
  ok($result[0] eq 'A/ABC');
}
