#
# WiKicker
#
#  Properties.t
#
#
# Copyright (C) 2003 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: Properties.t,v 1.1.1.1 2003/05/18 14:03:53 naney Exp $
#
#

use strict;

use Test;

BEGIN { plan test => 43 }

use WiKicker::Properties;

# test 1-2
{
  my $properties = WiKicker::Properties->new;
  ok(! defined($properties->get('key')));
  $properties->set('key', 'value');
  ok($properties->get('key') eq 'value');
}

# test 3-5
{
  my $parent = WiKicker::Properties->new;
  $parent->set('key1', 'parent');
  my $properties = WiKicker::Properties->new(parent => $parent);
  $properties->set('key2', 'child');
  ok($properties->get('key1') eq 'parent');
  ok($properties->get('key2') eq 'child');
  $properties->set('key1', 'new');
  ok($properties->get('key1') eq 'new');
}

# test 6-7
{
  my ($key, $value) = WiKicker::Properties::parse_line('key:value');
  ok($key eq 'key');
  ok($value eq 'value');
}

# test 8-9
{
  my ($key, $value) = WiKicker::Properties::parse_line('key :value');
  ok($key eq 'key');
  ok($value eq 'value');
}

# test 10-11
{
  my ($key, $value) = WiKicker::Properties::parse_line('key : value');
  ok($key eq 'key');
  ok($value eq 'value');
}

# test 12-13
{
  my ($key, $value) = WiKicker::Properties::parse_line('key: value');
  ok($key eq 'key');
  ok($value eq 'value');
}

# test 14-15
{
  my ($key, $value) = WiKicker::Properties::parse_line('key=value');
  ok($key eq 'key');
  ok($value eq 'value');
}

# test 16-17
{
  my ($key, $value) = WiKicker::Properties::parse_line('key =value');
  ok($key eq 'key');
  ok($value eq 'value');
}

# test 18-19
{
  my ($key, $value) = WiKicker::Properties::parse_line('key = value');
  ok($key eq 'key');
  ok($value eq 'value');
}

# test 20-21
{
  my ($key, $value) = WiKicker::Properties::parse_line('key= value');
  ok($key eq 'key');
  ok($value eq 'value');
}

# test 22-23
{
  my ($key, $value) = WiKicker::Properties::parse_line('key value');
  ok($key eq 'key');
  ok($value eq 'value');
}

# test 24-25
{
  my ($key, $value) = WiKicker::Properties::parse_line('key\ key value');
  ok($key eq 'key key');
  ok($value eq 'value');
}

# test 26-27
{
  my ($key, $value) = WiKicker::Properties::parse_line('key\:key:value');
  ok($key eq 'key:key');
  ok($value eq 'value');
}

# test 28-29
{
  my ($key, $value) = WiKicker::Properties::parse_line('key\=key=value');
  ok($key eq 'key=key');
  ok($value eq 'value');
}

# test 30-31
{
  my ($key, $value) = WiKicker::Properties::parse_line('key:value\tvalue');
  ok($key eq 'key');
  ok($value eq "value\tvalue");
}

# test 32-33
{
  my ($key, $value) = WiKicker::Properties::parse_line('key:value\nvalue');
  ok($key eq 'key');
  ok($value eq "value\nvalue");
}

# test 34-35
{
  my ($key, $value) = WiKicker::Properties::parse_line('key:value\rvalue');
  ok($key eq 'key');
  ok($value eq "value\rvalue");
}

# test 36-37
{
  my ($key, $value) = WiKicker::Properties::parse_line('key:value\\value');
  ok($key eq 'key');
  ok($value eq 'value\value');
}

# test 38-39
{
  my ($key, $value) = WiKicker::Properties::parse_line("key:value\\'value");
  ok($key eq 'key');
  ok($value eq "value'value");
}

# test 40-41
{
  my ($key, $value) = WiKicker::Properties::parse_line('key:value\"value');
  ok($key eq 'key');
  ok($value eq 'value"value');
}

# test 42-43
{
  my ($key, $value) = WiKicker::Properties::parse_line('key:value\ value');
  ok($key eq 'key');
  ok($value eq 'value value');
}
