#
# WiKicker
#
#  RSVisitor.t
#
#
# Copyright (C) 2003 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: RSVisitor.t,v 1.2 2003/10/26 23:07:34 naney Exp $
#
#
use strict;
use Test;

BEGIN { plan tests => 11 }

use WiKicker::WikiPage::DocumentParser;
use WiKicker::WikiPage::ReplaceSectionVisitor;
use WiKicker::WRI::Factory;

my $factory = WiKicker::WRI::Factory->new;

{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $visitor = WiKicker::WikiPage::ReplaceSectionVisitor->new;
  my $document_node = $parser->parse('');

  $visitor->section_number(-1);
  $visitor->new_section('abc');
  $visitor->visit($document_node);

  ok($visitor->new_raw eq "abc\n");
}

{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $visitor = WiKicker::WikiPage::ReplaceSectionVisitor->new;
  my $document_node = $parser->parse('');

  $visitor->section_number(-1);
  $visitor->new_section("abc\n");
  $visitor->visit($document_node);

  ok($visitor->new_raw eq "abc\n");
}

{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $visitor = WiKicker::WikiPage::ReplaceSectionVisitor->new;
  my $document_node = $parser->parse('');

  $visitor->section_number(0);
  $visitor->new_section("abc");
  $visitor->visit($document_node);

  ok($visitor->new_raw eq "abc\n");
}

{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $visitor = WiKicker::WikiPage::ReplaceSectionVisitor->new;
  my $document_node = $parser->parse('');

  $visitor->section_number(0);
  $visitor->new_section("abc\n");
  $visitor->visit($document_node);

  ok($visitor->new_raw eq "abc\n");
}

{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $visitor = WiKicker::WikiPage::ReplaceSectionVisitor->new;
  my $document_node = $parser->parse('');

  $visitor->section_number(1);
  $visitor->new_section("abc");
  $visitor->visit($document_node);

  ok($visitor->new_raw eq "abc\n");
}

{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $visitor = WiKicker::WikiPage::ReplaceSectionVisitor->new;
  my $document_node = $parser->parse('');

  $visitor->section_number(1);
  $visitor->new_section("abc\n");
  $visitor->visit($document_node);

  ok($visitor->new_raw eq "abc\n");
}

my $test_document_1 = <<__ENDSTR__;
abc
*h1
def
*h2
hij
__ENDSTR__

{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $visitor = WiKicker::WikiPage::ReplaceSectionVisitor->new;
  my $document_node = $parser->parse($test_document_1);

  $visitor->section_number(-1);
  $visitor->new_section("kkk");
  $visitor->visit($document_node);

  ok($visitor->new_raw eq <<__ENDSTR__);
abc
*h1
def
*h2
hij
kkk
__ENDSTR__
  
}

{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $visitor = WiKicker::WikiPage::ReplaceSectionVisitor->new;
  my $document_node = $parser->parse($test_document_1);

  $visitor->section_number(3);
  $visitor->new_section("kkk");
  $visitor->visit($document_node);

  ok($visitor->new_raw eq <<__ENDSTR__);
abc
*h1
def
*h2
hij
kkk
__ENDSTR__
  
}

{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $visitor = WiKicker::WikiPage::ReplaceSectionVisitor->new;
  my $document_node = $parser->parse($test_document_1);

  $visitor->section_number(0);
  $visitor->new_section("kkk");
  $visitor->visit($document_node);

  ok($visitor->new_raw eq <<__ENDSTR__);
kkk
*h1
def
*h2
hij
__ENDSTR__
  
}

{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $visitor = WiKicker::WikiPage::ReplaceSectionVisitor->new;
  my $document_node = $parser->parse($test_document_1);

  $visitor->section_number(1);
  $visitor->new_section("kkk");
  $visitor->visit($document_node);

  ok($visitor->new_raw eq <<__ENDSTR__);
abc
kkk
*h2
hij
__ENDSTR__
  
}

{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $visitor = WiKicker::WikiPage::ReplaceSectionVisitor->new;
  my $document_node = $parser->parse($test_document_1);

  $visitor->section_number(2);
  $visitor->new_section("kkk");
  $visitor->visit($document_node);

  ok($visitor->new_raw eq <<__ENDSTR__);
abc
*h1
def
kkk
__ENDSTR__
  
}
