#
# WiKicker
#
#  Rcs.t
#
#
# Copyright (C) 2003,2004,2005 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: Rcs.t,v 1.6 2005/05/10 12:56:30 naney Exp $
#
#

use strict;
use Test::More tests => 101;
use File::Path;

use WiKicker::Tie::Rcs;

use vars qw($dbdir);
$dbdir = 't/tmp/WiKicker-test-rcs';

rmtree([$dbdir], 0);

sub count_key {
  my $db = shift;

  return scalar(@{$db->all_keys_ref});
}

sub check_key_list {
  my ($db, @expect) = @_;

  @expect = sort @expect;
  my @db_keys = sort @{$db->all_keys_ref};

  return 0 unless @expect == @db_keys;
  for (my $i = 0; $i < @expect; $i++) {
    return 0 if $expect[$i] ne $db_keys[$i];
  }
  return 1;
}

sub check_RCS_file {
  my $file_name = shift;

  if ($^O =~ /Win32/) {
    return -e "$dbdir/RCS/$file_name";
  }
  else {
    return -e "$dbdir/RCS/$file_name,v";
  }
}

{
  my %db_hash;
  my $db = tie(%db_hash, 'WiKicker::Tie::Rcs', $dbdir);
  is(count_key($db), 0);
  # 1.1 ---
  # dog
  $db_hash{key} = 'dog';
  is(count_key($db), 1);
  ok(check_key_list($db, 'key'));
  is($db_hash{key}, 'dog');
  is($db->head_revision_no('key'), '1.1');
  is($db->latest_revision_no('key'), '1.1');
  is($db->get_revision('key', '1.1'), 'dog');
  is($db->get_head_revision('key'), 'dog');
  if ($^O =~ /Win32/) {
    ok(-e "$dbdir/NNSXS");
    ok(check_RCS_file('NNSXS'));
  }
  else {
    ok(-e "$dbdir/a2V5");
    ok(check_RCS_file('a2V5'));
  }

  # 1.1 ---
  # dog
  # work ---
  # dok
  $db_hash{key} = 'dok';
  is(count_key($db), 1);
  is($db_hash{key}, 'dok');
  is($db->head_revision_no('key'), '1.1');
  is($db->latest_revision_no('key'), '1.2');
  is($db->get_revision('key', '1.1'), 'dog');
  is($db->get_head_revision('key'), 'dog');
  # 1.1 ---
  # dog
  # work ---
  # $Id: Rcs.t,v 1.6 2005/05/10 12:56:30 naney Exp $
  $db_hash{key} = '$Id: Rcs.t,v 1.6 2005/05/10 12:56:30 naney Exp $';
  is($db_hash{key}, '$Id: Rcs.t,v 1.6 2005/05/10 12:56:30 naney Exp $');
  is($db->head_revision_no('key'), '1.1');
  is($db->latest_revision_no('key'), '1.2');
  is($db->get_revision('key', '1.1'), 'dog');
  is($db->get_head_revision('key'), 'dog');

  undef $db;
  untie %db_hash;
}

{
  my %db_hash;
  my $db = tie(%db_hash, 'WiKicker::Tie::Rcs', $dbdir);
  is(count_key($db), 1);
  is($db_hash{key}, '$Id: Rcs.t,v 1.6 2005/05/10 12:56:30 naney Exp $');

  undef $db;
  untie %db_hash;
}

{
  my %db_hash;
  my $db = tie(%db_hash, 'WiKicker::Tie::Rcs',
               $dbdir,
               { force_check_in => 1});
  is($db_hash{key}, '$Id: Rcs.t,v 1.6 2005/05/10 12:56:30 naney Exp $');
  # 1.2 ---
  # $Id: Rcs.t,v 1.6 2005/05/10 12:56:30 naney Exp $
  # work ---
  # dog
  # cat
  $db_hash{key} = "dog\ncat";

  is($db_hash{key}, "dog\ncat");
  is($db->head_revision_no('key'), '1.2');
  is($db->latest_revision_no('key'), '1.3');
  is($db->get_revision('key', '1.1'), 'dog');
  is($db->get_revision('key', '1.2'), '$Id: Rcs.t,v 1.6 2005/05/10 12:56:30 naney Exp $');
  is($db->get_head_revision('key'), '$Id: Rcs.t,v 1.6 2005/05/10 12:56:30 naney Exp $');

  undef $db;
  untie %db_hash;
}

# test after force_check_in
{
  my %db_hash;
  my $db = tie(%db_hash, 'WiKicker::Tie::Rcs',
               $dbdir);
  is($db_hash{key}, "dog\ncat");
  # work ---
  # dog
  # cat
  # ant
  $db_hash{key} = "dog\ncat\nant";

  is($db_hash{key}, "dog\ncat\nant");
  is($db->head_revision_no('key'), '1.2');
  is($db->latest_revision_no('key'), '1.3');
  is($db->get_revision('key', '1.1'), 'dog');
  is($db->get_revision('key', '1.2'), '$Id: Rcs.t,v 1.6 2005/05/10 12:56:30 naney Exp $');
  is($db->get_head_revision('key', '1.2'), '$Id: Rcs.t,v 1.6 2005/05/10 12:56:30 naney Exp $');

  undef $db;
  untie %db_hash;
}

# test check_in_interval
{
  sleep(4);
  my %db_hash;
  my $db = tie(%db_hash, 'WiKicker::Tie::Rcs',
               $dbdir,
              {check_in_interval => 3});
  # 1.3 ---
  # dog
  # cat
  # ant
  # work ---
  # mmm
  is($db_hash{key}, "dog\ncat\nant");
  $db_hash{key} = 'mmm';

  is($db_hash{key}, 'mmm');
  is($db->head_revision_no('key'), '1.3');
  is($db->latest_revision_no('key'), '1.4');
  is($db->get_revision('key', '1.1'), 'dog');
  is($db->get_revision('key', '1.2'), '$Id: Rcs.t,v 1.6 2005/05/10 12:56:30 naney Exp $');
  is($db->get_revision('key', '1.3'), "dog\ncat\nant");
  is($db->get_head_revision('key'), "dog\ncat\nant");

  undef $db;
  untie %db_hash;
}

# test log
{
  my %db_hash;
  my $db = tie(%db_hash, 'WiKicker::Tie::Rcs',
               $dbdir);
  is($db_hash{key}, 'mmm');
  is($db->head_revision_no('key'), '1.3');
  is($db->latest_revision_no('key'), '1.4');
  is($db->get_revision('key', '1.1'), 'dog');
  is($db->get_revision('key', '1.2'), '$Id: Rcs.t,v 1.6 2005/05/10 12:56:30 naney Exp $');
  is($db->get_revision('key', '1.3'), "dog\ncat\nant");
  is($db->get_head_revision('key'), "dog\ncat\nant");

  my @log = $db->log('key');
  ok(@log == 3);
  is($log[0]->[0], '1.3');
  is($log[1]->[0], '1.2');
  is($log[2]->[0], '1.1');
  is($log[0]->[2], '3');
  is($log[0]->[3], '1');
  is($log[1]->[2], '1');
  is($log[1]->[3], '1');
  is($log[2]->[2], '-1');
  is($log[2]->[3], '-1');
}

# delete
{
  my %db_hash;
  my $db = tie(%db_hash, 'WiKicker::Tie::Rcs',
               $dbdir);
  ok(exists $db_hash{key});
  is(count_key($db), 1);
  is($db_hash{key}, 'mmm');
  ok(-e $db->file_full_name('key'));
  ok(-e $db->rcs_full_name('key'));
  ok($db->exists_backup('key'));

  delete $db_hash{key};
  is(count_key($db), 0);
  ok(! exists $db_hash{key});
  ok(!-e $db->file_full_name('key'));
  ok(-e $db->rcs_full_name('key'));
  ok($db->exists_backup('key'));
}

# delete and new
{
  my %db_hash;
  my $db = tie(%db_hash, 'WiKicker::Tie::Rcs', $dbdir);

  is(count_key($db), 0);
  $db_hash{delete_new} = 'test';
  is(count_key($db), 1);
  ok(check_key_list($db, 'delete_new'));
  is($db_hash{delete_new}, 'test');
  is($db->head_revision_no('delete_new'), '1.1');
  is($db->latest_revision_no('delete_new'), '1.1');
  is($db->get_revision('delete_new', '1.1'), 'test');
  is($db->get_head_revision('delete_new'), 'test');

  delete $db_hash{delete_new};
  is(count_key($db), 0);
  ok(! exists $db_hash{delete_new});
  ok(!-e $db->file_full_name('delete_new'));
  ok($db->exists_backup('delete_new'));

  $db_hash{delete_new} = 'test2';
  is(count_key($db), 1);
  ok(check_key_list($db, 'delete_new'));
  is($db_hash{delete_new}, 'test2');
  is($db->head_revision_no('delete_new'), '2.1');
  is($db->latest_revision_no('delete_new'), '2.1');
  is($db->get_revision('delete_new', '2.1'), 'test2');
  is($db->get_revision('delete_new', '1.1'), 'test');
  is($db->get_head_revision('delete_new'), 'test2');
}

# mojibake?
{
  my %db_hash;
  my $db = tie(%db_hash, 'WiKicker::Tie::Rcs', $dbdir);

  is(count_key($db), 1);
  $db_hash{JapaneseString} = ',[[HedwigAndTheAngryInch]] ,やまだ:★★★ まさき:★★★';
  is($db_hash{JapaneseString}, ',[[HedwigAndTheAngryInch]] ,やまだ:★★★ まさき:★★★');
  is(count_key($db), 2);
  ok(check_key_list($db, 'delete_new', 'JapaneseString'));
}

# japanese key
{
  my %db_hash;
  my $db = tie(%db_hash, 'WiKicker::Tie::Rcs', $dbdir);

  $db_hash{'あいう'} = 'abcdef';
  is($db_hash{'あいう'}, 'abcdef');
  ok(check_key_list($db, 'delete_new', 'JapaneseString', 'あいう'));
}

{
  my %db_hash;
  my $db = tie(%db_hash, 'WiKicker::Tie::Rcs', $dbdir);

  ok(unlink("$dbdir/index"));
  ok(check_key_list($db, 'delete_new', 'JapaneseString', 'あいう'));
}
