#
# WiKicker
#
#  Request.t
#
#
# Copyright (C) 2003,2004 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: Request.t,v 1.4 2004/04/30 08:28:53 naney Exp $
#
#

use strict;
use Test;

BEGIN { plan tests => 41 }

use CGI qw(-no_debug);
use WiKicker::WikiCGI::Request;

# ?PageName
{
  my $query = CGI->new('PageName');
  my $request = WiKicker::WikiCGI::Request->new(environment => undef,
                                                query => $query);
  ok($request->name eq 'PageName');
  ok($request->action eq 'read');
  ok($request->format eq 'html');
}

# ?name=PageName&action=read
{
  my $query = CGI->new('name=PageName');
  my $request = WiKicker::WikiCGI::Request->new(environment => undef,
                                                query => $query);
  ok($request->name eq 'PageName');
  ok($request->action eq 'read');
  ok($request->format eq 'html');
}

# ?name=PageName&action=read
{
  my $query = CGI->new('name=PageName&action=read');
  my $request = WiKicker::WikiCGI::Request->new(environment => undef,
                                                query => $query);
  ok($request->name eq 'PageName');
  ok($request->action eq 'read');
  ok($request->format eq 'html');
}

# ?name=PageName&action=edit
{
  my $query = CGI->new('name=PageName&action=edit');
  my $request = WiKicker::WikiCGI::Request->new(environment => undef,
                                                query => $query);
  ok($request->name eq 'PageName');
  ok($request->action eq 'edit');
  ok($request->format eq 'html');
}

# ?read=PageName
{
  my $query = CGI->new('read=PageName');
  my $request = WiKicker::WikiCGI::Request->new(environment => undef,
                                                query => $query);
  ok($request->name eq 'PageName');
  ok($request->action eq 'read');
  ok($request->format eq 'html');
}

# ?read=PageName&format=raw
{
  my $query = CGI->new('read=PageName&format=raw');
  my $request = WiKicker::WikiCGI::Request->new(environment => undef,
                                                query => $query);
  ok($request->name eq 'PageName');
  ok($request->action eq 'read');
  ok($request->format eq 'raw');
}

# ?name=PageName&action=read&format=raw
{
  my $query = CGI->new('name=PageName&action=read&format=raw');
  my $request = WiKicker::WikiCGI::Request->new(environment => undef,
                                                query => $query);
  ok($request->name eq 'PageName');
  ok($request->action eq 'read');
  ok($request->format eq 'raw');
}

# attribute setter and getter
{
  my $query = CGI->new;
  my $request = WiKicker::WikiCGI::Request->new(environment => undef,
                                                query => $query);
  $request->attribute('key', 'dog');
  ok($request->attribute('key') eq 'dog');
}

# /Naney
{
  $ENV{PATH_INFO} = '/Naney';
  my $query = CGI->new;
  my $request = WiKicker::WikiCGI::Request->new(environment => undef,
                                                query => $query);
  ok($request->name eq 'Naney');
  ok($request->action eq 'read');
  ok($request->format eq 'html');
}

# /Naney.html
{
  $ENV{PATH_INFO} = '/Naney.html';
  my $query = CGI->new;
  my $request = WiKicker::WikiCGI::Request->new(environment => undef,
                                                query => $query);
  ok($request->name eq 'Naney');
  ok($request->action eq 'read');
  ok($request->format eq 'html');
}

# /Naney.txt
{
  $ENV{PATH_INFO} = '/Naney.txt';
  my $query = CGI->new;
  my $request = WiKicker::WikiCGI::Request->new(environment => undef,
                                                query => $query);
  ok($request->name eq 'Naney');
  ok($request->action eq 'read');
  ok($request->format eq 'txt');
}

# /Naney.html?edit
{
  $ENV{PATH_INFO} = '/Naney.html';
  my $query = CGI->new('edit');
  my $request = WiKicker::WikiCGI::Request->new(environment => undef,
                                                query => $query);
  ok($request->name eq 'Naney');
  ok($request->action eq 'edit');
  ok($request->format eq 'html');
}

# /Naney.html?action=edit
{
  $ENV{PATH_INFO} = '/Naney.html';
  my $query = CGI->new('action=edit');
  my $request = WiKicker::WikiCGI::Request->new(environment => undef,
                                                query => $query);
  ok($request->name eq 'Naney');
  ok($request->action eq 'edit');
  ok($request->format eq 'html');
}

{
  my $query = CGI->new;
  my $request = WiKicker::WikiCGI::Request->new(environment => undef,
                                                query => $query);
  my $result = $request->is_self_uri('http://www.naney.org/wiki',
                                     'http://www.naney.org/wiki');
  ok(defined $result);
  ok($result eq '');
}

{
  my $query = CGI->new;
  my $request = WiKicker::WikiCGI::Request->new(environment => undef,
                                                query => $query);
  my $result = $request->is_self_uri('http://www.naney.org/wiki/a',
                                     'http://www.naney.org/wiki');
  ok($result eq 'a');
}

{
  my $query = CGI->new;
  my $request = WiKicker::WikiCGI::Request->new(environment => undef,
                                                query => $query);
  my $result = $request->is_self_uri('http://www.naney.org/wiki/a.html',
                                     'http://www.naney.org/wiki');
  ok($result eq 'a');
}
