#
# WiKicker
#
#  RobotUriQueue.t
#
#
# Copyright (C) 2003,2005 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: RobotUriQueue.t,v 1.3 2005/03/26 09:00:37 naney Exp $
#
#

use strict;
use Test::More;

use vars qw($skip);

BEGIN {
  eval "use Tie::IxHash";
  if ($@) {
    plan skip_all => "Can't use Tie::IxHash";
    exit;
  }
  else {
    plan tests => 24;
  }
}

BEGIN {
  use_ok('WiKicker::WWW::Robot::RobotUriQueue');
}

{
  my $queue = WiKicker::WWW::Robot::RobotUriQueue->new;
  ok(!defined $queue->next_open_time);
  ok(!defined $queue->next_uri);
  ok($queue->host_count == 0);

  $queue->add('http://www.naney.org/index.html', 5);
  ok($queue->host_count == 1);
  ok($queue->next_open_time == 5);
  ok($queue->next_uri eq 'http://www.naney.org/index.html');
  ok($queue->host_count == 0);
}

{
  my $queue = WiKicker::WWW::Robot::RobotUriQueue->new;
  $queue->add('http://www.naney.org/index.html', 5);
  ok($queue->host_count == 1);
  ok($queue->next_open_time == 5);
  $queue->add('http://www.naney.org/index2.html', 6);
  ok($queue->host_count == 1);
  ok($queue->next_open_time == 6);

  ok($queue->next_uri eq 'http://www.naney.org/index.html');
  ok($queue->host_count == 1);
  ok($queue->next_uri eq 'http://www.naney.org/index2.html');
  ok($queue->host_count == 0);
}

{
  my $queue = WiKicker::WWW::Robot::RobotUriQueue->new;
  $queue->add('http://www.naney.org/index.html', 5);
  ok($queue->host_count == 1);
  ok($queue->next_open_time == 5);
  $queue->add('http://www2.naney.org/index.html', 4);
  ok($queue->host_count == 2);
  ok($queue->next_open_time == 4);

  ok($queue->next_uri eq 'http://www2.naney.org/index.html');
  ok($queue->host_count == 1);
  ok($queue->next_uri eq 'http://www.naney.org/index.html');
  ok($queue->host_count == 0);
}
