#
# WiKicker
#
#  TermDB.t
#
#
# Copyright (C) 2005 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: TermDB.t,v 1.3 2005/05/06 13:00:55 naney Exp $
#
#

use strict;
use Test::More;

BEGIN {
  eval "use DB_File::Lock";
  if ($@) {
    plan skip_all => "Can't use DB_File::Lock";
    exit;
  }
  else {
    plan tests => 6;
  }
}

use File::Path;
use Log::Log4perl qw(:easy);
Log::Log4perl->easy_init($ERROR);

use WiKicker::DikiCGI::Configuration;
use WiKicker::DikiCGI::Environment;
use WiKicker::Diki::TermDB;

sub FILE_NAME {
  return 't/tmp/TermDB/term.db';
}


#=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
#    setup
#-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
BEGIN {
  unless (-e 't/tmp/TermDB') {
    mkpath('t/tmp/TermDB', 0, 0755);
    mkpath('t/tmp/TermDB/primary', 0, 0755);
  }
  open(PROPERTIES, '>t/tmp/TermDB/test.properties') || die;
  print PROPERTIES 'dikicker.database.directory: t/tmp/TermDB';
  close(PROPERTIES);
}

END {
  rmtree('t/tmp/TermDB', 0);
}

my $configuration = WiKicker::DikiCGI::Configuration->new(properties_file => 't/tmp/TermDB/test.properties');
my $env = WiKicker::DikiCGI::Environment->new(configuration => $configuration);
$ENV{SCRIPT_NAME} = 'dummy.cgi';

#=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
#    new without file_name
#-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
eval {
  WiKicker::Diki::TermDB->new;
};
if ($@) {
  ok(1);
}
else {
  ok(0);
}

#=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
#    new
#-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
my $db;
eval {
  $db = WiKicker::Diki::TermDB->new(file_name => FILE_NAME());
};
if ($@) {
  ok(0);
  #ok(0, 1, $@);
}
else {
  ok(1);
  #ok(1);
}

my ($term_list, $time) = $db->term_list;
ok(@$term_list == 0);

my $article_text = <<__ENDSTR__;
* [[test]]
test
__ENDSTR__

my $now = time;
my $article = WiKicker::Diki::DiaryArticle->new(text => $article_text,
                                                id => '2005-01-01-abc',
                                                last_modified => $now,
                                                term_list => $term_list,
                                                term_list_modified => $time,
                                                environment => $env);

$db->regist_diary_article($article);

($term_list, $time) = $db->term_list;

is(@$term_list, 1);


$article_text = <<__ENDSTR__;
* test
[[test1]]
[[test2]]
__ENDSTR__

sleep(2);

$now = time;
$article = WiKicker::Diki::DiaryArticle->new(text => $article_text,
                                             id => '2005-01-02-abc',
                                             last_modified => $now,
                                             term_list => $term_list,
                                             term_list_modified => $time,
                                             environment => $env);

$db->regist_diary_article($article);

($term_list, $time) = $db->term_list;

is(@$term_list, 3);


undef $db;

$db = WiKicker::Diki::TermDB->new(file_name => FILE_NAME());

($term_list, $time) = $db->term_list;

is(@$term_list, 3);
