#
# WiKicker
#
#  Time.t
#
#
# Copyright (C) 2003,2004,2005 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: Time.t,v 1.10 2005/03/06 04:44:48 naney Exp $
#
#

use strict;
use Test;

BEGIN { plan tests => 200 }

use WiKicker::Time;

# gmtime
{
  my ($sec, $min, $hour, $mday, $mon, $year, $wday, $yday, $isdst)
    = WiKicker::Time::zonetime(0, 'GMT');
  ok($sec == 0);
  ok($min == 0);
  ok($hour == 0);
  ok($mday == 1);
  ok($mon == 0);
  ok($year == 70);
  ok($wday == 4);
  ok($yday == 0);
  ok($isdst == 0);
}

#jst
{
  my ($sec, $min, $hour, $mday, $mon, $year, $wday, $yday, $isdst)
    = WiKicker::Time::zonetime(0, 'JST-9');
  ok($sec == 0);
  ok($min == 0);
  ok($hour == 9);
  ok($mday == 1);
  ok($mon == 0);
  ok($year == 70);
  ok($wday == 4);
  ok($yday == 0);
  ok($isdst == 0);
}

{
  my $gmtime = WiKicker::Time::W3CDTF_to_gmtime('1997');
  my ($sec, $min, $hour, $mday, $mon, $year, $wday, $yday) = gmtime($gmtime);
  ok($sec == 0);
  ok($min == 0);
  ok($hour == 0);
  ok($mday == 1);
  ok($mon == 0);
  ok($year == 97);
  ok(WiKicker::Time::gmtime_to_W3CDTF_UTC($gmtime) eq '1997-01-01T00:00:00Z');
}

{
  my $gmtime = WiKicker::Time::W3CDTF_to_gmtime('1997-07');
  my ($sec, $min, $hour, $mday, $mon, $year, $wday, $yday) = gmtime($gmtime);
  ok($sec == 0);
  ok($min == 0);
  ok($hour == 0);
  ok($mday == 1);
  ok($mon == 6);
  ok($year == 97);
  ok(WiKicker::Time::gmtime_to_W3CDTF_UTC($gmtime) eq '1997-07-01T00:00:00Z');
}

{
  my $gmtime = WiKicker::Time::W3CDTF_to_gmtime('1997-07-16');
  my ($sec, $min, $hour, $mday, $mon, $year, $wday, $yday) = gmtime($gmtime);
  ok($sec == 0);
  ok($min == 0);
  ok($hour == 0);
  ok($mday == 16);
  ok($mon == 6);
  ok($year == 97);
  ok(WiKicker::Time::gmtime_to_W3CDTF_UTC($gmtime) eq '1997-07-16T00:00:00Z');
}

{
  my $gmtime = WiKicker::Time::W3CDTF_to_gmtime('1997-07-16T19:20+01:00');
  my ($sec, $min, $hour, $mday, $mon, $year, $wday, $yday) = gmtime($gmtime);
  ok($sec == 0);
  ok($min == 20);
  ok($hour == 18);
  ok($mday == 16);
  ok($mon == 6);
  ok($year == 97);
  ok(WiKicker::Time::gmtime_to_W3CDTF_UTC($gmtime) eq '1997-07-16T18:20:00Z');
}

{
  my $gmtime = WiKicker::Time::W3CDTF_to_gmtime('1997-07-16T19:20:30+01:00');
  my ($sec, $min, $hour, $mday, $mon, $year, $wday, $yday) = gmtime($gmtime);
  ok($sec == 30);
  ok($min == 20);
  ok($hour == 18);
  ok($mday == 16);
  ok($mon == 6);
  ok($year == 97);
  ok(WiKicker::Time::gmtime_to_W3CDTF_UTC($gmtime) eq '1997-07-16T18:20:30Z');
}

{
  my $gmtime = WiKicker::Time::W3CDTF_to_gmtime('1997-07-16T19:20:30.45+01:00');
  my ($sec, $min, $hour, $mday, $mon, $year, $wday, $yday) = gmtime($gmtime);
  ok($sec == 30);
  ok($min == 20);
  ok($hour == 18);
  ok($mday == 16);
  ok($mon == 6);
  ok($year == 97);
  ok(WiKicker::Time::gmtime_to_W3CDTF_UTC($gmtime) eq '1997-07-16T18:20:30Z');
}

{
  my $gmtime = WiKicker::Time::W3CDTF_to_gmtime('1994-11-05T08:15:30-05:00');
  my ($sec, $min, $hour, $mday, $mon, $year, $wday, $yday) = gmtime($gmtime);
  ok($sec == 30);
  ok($min == 15);
  ok($hour == 13);
  ok($mday == 5);
  ok($mon == 10);
  ok($year == 94);
  ok(WiKicker::Time::gmtime_to_W3CDTF_UTC($gmtime) eq '1994-11-05T13:15:30Z');
}

{
  my $gmtime = WiKicker::Time::W3CDTF_to_gmtime('1994-11-05T13:15:30Z');
  my ($sec, $min, $hour, $mday, $mon, $year, $wday, $yday) = gmtime($gmtime);
  ok($sec == 30);
  ok($min == 15);
  ok($hour == 13);
  ok($mday == 5);
  ok($mon == 10);
  ok($year == 94);
  ok(WiKicker::Time::gmtime_to_W3CDTF_UTC($gmtime) eq '1994-11-05T13:15:30Z');
}

{
  my $gmtime = WiKicker::Time::W3CDTF_to_gmtime('2003-01-33T00:00:00Z');
  ok(! defined $gmtime);
}


{
  my $time = time;
  ok(WiKicker::Time::RFC1123_to_gmtime(WiKicker::Time::gmtime_to_RFC1123($time)) == $time);
}

{
  # before year
  ok(WiKicker::Time::japanese_date_only_str('2003', '01', '01', 'GMT'),
     '2003年01月01日(水)');
  # last year
  ok(WiKicker::Time::japanese_date_only_str('2004', '01', '01', 'GMT'),
     '2004年01月01日(木)');
  # this year
  ok(WiKicker::Time::japanese_date_only_str('2005', '01', '01', 'GMT'),
     '01月01日(土)');
}


{
  ok(!WiKicker::Time::day_in_ten_day('00', 'a'));
  ok(WiKicker::Time::day_in_ten_day('01', 'a'));
  ok(WiKicker::Time::day_in_ten_day('02', 'a'));
  ok(WiKicker::Time::day_in_ten_day('03', 'a'));
  ok(WiKicker::Time::day_in_ten_day('04', 'a'));
  ok(WiKicker::Time::day_in_ten_day('05', 'a'));
  ok(WiKicker::Time::day_in_ten_day('06', 'a'));
  ok(WiKicker::Time::day_in_ten_day('07', 'a'));
  ok(WiKicker::Time::day_in_ten_day('08', 'a'));
  ok(WiKicker::Time::day_in_ten_day('09', 'a'));
  ok(WiKicker::Time::day_in_ten_day('10', 'a'));
  ok(!WiKicker::Time::day_in_ten_day('11', 'a'));
  ok(!WiKicker::Time::day_in_ten_day('12', 'a'));
  ok(!WiKicker::Time::day_in_ten_day('13', 'a'));
  ok(!WiKicker::Time::day_in_ten_day('14', 'a'));
  ok(!WiKicker::Time::day_in_ten_day('15', 'a'));
  ok(!WiKicker::Time::day_in_ten_day('16', 'a'));
  ok(!WiKicker::Time::day_in_ten_day('17', 'a'));
  ok(!WiKicker::Time::day_in_ten_day('18', 'a'));
  ok(!WiKicker::Time::day_in_ten_day('19', 'a'));
  ok(!WiKicker::Time::day_in_ten_day('20', 'a'));
  ok(!WiKicker::Time::day_in_ten_day('21', 'a'));
  ok(!WiKicker::Time::day_in_ten_day('22', 'a'));
  ok(!WiKicker::Time::day_in_ten_day('23', 'a'));
  ok(!WiKicker::Time::day_in_ten_day('24', 'a'));
  ok(!WiKicker::Time::day_in_ten_day('25', 'a'));
  ok(!WiKicker::Time::day_in_ten_day('26', 'a'));
  ok(!WiKicker::Time::day_in_ten_day('27', 'a'));
  ok(!WiKicker::Time::day_in_ten_day('28', 'a'));
  ok(!WiKicker::Time::day_in_ten_day('29', 'a'));
  ok(!WiKicker::Time::day_in_ten_day('30', 'a'));
  ok(!WiKicker::Time::day_in_ten_day('31', 'a'));
  ok(!WiKicker::Time::day_in_ten_day('32', 'a'));

  ok(!WiKicker::Time::day_in_ten_day('00', 'b'));
  ok(!WiKicker::Time::day_in_ten_day('01', 'b'));
  ok(!WiKicker::Time::day_in_ten_day('02', 'b'));
  ok(!WiKicker::Time::day_in_ten_day('03', 'b'));
  ok(!WiKicker::Time::day_in_ten_day('04', 'b'));
  ok(!WiKicker::Time::day_in_ten_day('05', 'b'));
  ok(!WiKicker::Time::day_in_ten_day('06', 'b'));
  ok(!WiKicker::Time::day_in_ten_day('07', 'b'));
  ok(!WiKicker::Time::day_in_ten_day('08', 'b'));
  ok(!WiKicker::Time::day_in_ten_day('09', 'b'));
  ok(!WiKicker::Time::day_in_ten_day('10', 'b'));
  ok(WiKicker::Time::day_in_ten_day('11', 'b'));
  ok(WiKicker::Time::day_in_ten_day('12', 'b'));
  ok(WiKicker::Time::day_in_ten_day('13', 'b'));
  ok(WiKicker::Time::day_in_ten_day('14', 'b'));
  ok(WiKicker::Time::day_in_ten_day('15', 'b'));
  ok(WiKicker::Time::day_in_ten_day('16', 'b'));
  ok(WiKicker::Time::day_in_ten_day('17', 'b'));
  ok(WiKicker::Time::day_in_ten_day('18', 'b'));
  ok(WiKicker::Time::day_in_ten_day('19', 'b'));
  ok(WiKicker::Time::day_in_ten_day('20', 'b'));
  ok(!WiKicker::Time::day_in_ten_day('21', 'b'));
  ok(!WiKicker::Time::day_in_ten_day('22', 'b'));
  ok(!WiKicker::Time::day_in_ten_day('23', 'b'));
  ok(!WiKicker::Time::day_in_ten_day('24', 'b'));
  ok(!WiKicker::Time::day_in_ten_day('25', 'b'));
  ok(!WiKicker::Time::day_in_ten_day('26', 'b'));
  ok(!WiKicker::Time::day_in_ten_day('27', 'b'));
  ok(!WiKicker::Time::day_in_ten_day('28', 'b'));
  ok(!WiKicker::Time::day_in_ten_day('29', 'b'));
  ok(!WiKicker::Time::day_in_ten_day('30', 'b'));
  ok(!WiKicker::Time::day_in_ten_day('31', 'b'));
  ok(!WiKicker::Time::day_in_ten_day('32', 'b'));

  ok(!WiKicker::Time::day_in_ten_day('00', 'c'));
  ok(!WiKicker::Time::day_in_ten_day('01', 'c'));
  ok(!WiKicker::Time::day_in_ten_day('02', 'c'));
  ok(!WiKicker::Time::day_in_ten_day('03', 'c'));
  ok(!WiKicker::Time::day_in_ten_day('04', 'c'));
  ok(!WiKicker::Time::day_in_ten_day('05', 'c'));
  ok(!WiKicker::Time::day_in_ten_day('06', 'c'));
  ok(!WiKicker::Time::day_in_ten_day('07', 'c'));
  ok(!WiKicker::Time::day_in_ten_day('08', 'c'));
  ok(!WiKicker::Time::day_in_ten_day('09', 'c'));
  ok(!WiKicker::Time::day_in_ten_day('10', 'c'));
  ok(!WiKicker::Time::day_in_ten_day('11', 'c'));
  ok(!WiKicker::Time::day_in_ten_day('12', 'c'));
  ok(!WiKicker::Time::day_in_ten_day('13', 'c'));
  ok(!WiKicker::Time::day_in_ten_day('14', 'c'));
  ok(!WiKicker::Time::day_in_ten_day('15', 'c'));
  ok(!WiKicker::Time::day_in_ten_day('16', 'c'));
  ok(!WiKicker::Time::day_in_ten_day('17', 'c'));
  ok(!WiKicker::Time::day_in_ten_day('18', 'c'));
  ok(!WiKicker::Time::day_in_ten_day('19', 'c'));
  ok(!WiKicker::Time::day_in_ten_day('20', 'c'));
  ok(WiKicker::Time::day_in_ten_day('21', 'c'));
  ok(WiKicker::Time::day_in_ten_day('22', 'c'));
  ok(WiKicker::Time::day_in_ten_day('23', 'c'));
  ok(WiKicker::Time::day_in_ten_day('24', 'c'));
  ok(WiKicker::Time::day_in_ten_day('25', 'c'));
  ok(WiKicker::Time::day_in_ten_day('26', 'c'));
  ok(WiKicker::Time::day_in_ten_day('27', 'c'));
  ok(WiKicker::Time::day_in_ten_day('28', 'c'));
  ok(WiKicker::Time::day_in_ten_day('29', 'c'));
  ok(WiKicker::Time::day_in_ten_day('30', 'c'));
  ok(WiKicker::Time::day_in_ten_day('31', 'c'));
  ok(!WiKicker::Time::day_in_ten_day('32', 'c'));
}

{
  ok(WiKicker::Time::_good_mday(2004,2,29));
}

{
  ok(WiKicker::Time::previous_day_str('2004-03-12'), '2004-03-11');

  ok(WiKicker::Time::previous_day_str('2004-01-01'), '2003-12-31');
  ok(WiKicker::Time::previous_day_str('2004-02-01'), '2004-01-31');
  ok(WiKicker::Time::previous_day_str('2004-03-01'), '2004-02-29');
  ok(WiKicker::Time::previous_day_str('2004-04-01'), '2004-03-31');
  ok(WiKicker::Time::previous_day_str('2004-05-01'), '2004-04-30');
  ok(WiKicker::Time::previous_day_str('2004-06-01'), '2004-05-31');
  ok(WiKicker::Time::previous_day_str('2004-07-01'), '2004-06-30');
  ok(WiKicker::Time::previous_day_str('2004-08-01'), '2004-07-31');
  ok(WiKicker::Time::previous_day_str('2004-09-01'), '2004-08-31');
  ok(WiKicker::Time::previous_day_str('2004-10-01'), '2004-09-30');
  ok(WiKicker::Time::previous_day_str('2004-11-01'), '2004-10-31');
  ok(WiKicker::Time::previous_day_str('2004-12-01'), '2004-11-30');

  ok(WiKicker::Time::previous_day_str('2003-03-01'), '2003-02-28');
}

{
  # before year
  my $gmtime = WiKicker::Time::W3CDTF_to_gmtime('2003-01-01T00:00:00Z');
  ok(WiKicker::Time::english_date_html_str($gmtime, 'GMT'),
    qq(<span title="Wed Jan 01 00:00:00 GMT 2003"><span class="Wednesday">Wed</span> Jan 01 00:00 2003</span>));

  # last year
  $gmtime = WiKicker::Time::W3CDTF_to_gmtime('2004-01-01T00:00:00Z');
  ok(WiKicker::Time::english_date_html_str($gmtime, 'GMT'),
    qq(<span title="Thu Jan 01 00:00:00 GMT 2004"><span class="Thursday">Thu</span> Jan 01 00:00 2004</span>));

  # this year
  $gmtime = WiKicker::Time::W3CDTF_to_gmtime('2005-01-01T00:00:00Z');
  ok(WiKicker::Time::english_date_html_str($gmtime, 'GMT'),
    qq(<span title="Sat Jan 01 00:00:00 GMT 2005"><span class="Saturday">Sat</span> Jan 01 00:00</span>));
}

{
  ok(WiKicker::Time::english_date_only_html_str(2003, 1, 1, 'GMT'),
    qq(<span title="Wed Jan 01 2003"><span class="Wednesday">Wed</span> Jan 01 2003</span>));

  ok(WiKicker::Time::english_date_only_html_str(2004, 1, 1, 'GMT'),
    qq(<span title="Thu Jan 01 2004"><span class="Thursday">Thu</span> Jan 01 2004</span>));

  ok(WiKicker::Time::english_date_only_html_str(2005, 1, 1, 'GMT'),
    qq(<span title="Sat Jan 01 2005"><span class="Saturday">Sat</span> Jan 01</span>));
}

ok(WiKicker::Time::japanese_wday_str(2005,03,06), '日');
