#
# WiKicker
#
#  URI.t
#
#
# Copyright (C) 2003,2004 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: URI.t,v 1.5 2004/06/06 12:59:16 naney Exp $
#
#

use strict;
use Test;

BEGIN { plan tests => 30 }

use WiKicker::URI;

{
  ok(WiKicker::URI::page_name_to_path_segments('a') eq 'a');
  ok(WiKicker::URI::page_name_to_path_segments('a/b') eq 'a/b');
  ok(WiKicker::URI::page_name_to_path_segments('日本') eq '%e6%97%a5%e6%9c%ac');
  ok(WiKicker::URI::page_name_to_path_segments('日本/東京')
     eq ('%e6%97%a5%e6%9c%ac' . '/' . '%e6%9d%b1%e4%ba%ac'));

  # no escape '-'
  ok(WiKicker::URI::page_name_to_path_segments('E-TTL') eq 'E-TTL');

  # no escape RFC2296 mark
  ok(WiKicker::URI::page_name_to_path_segments("-_.!~*'()") eq "-_.!~*'()");

  # no escape RFC2296 :@&=+$.
  ok(WiKicker::URI::page_name_to_path_segments(':@&=+$.') eq ':@&=+$.');
}

{
  ok(WiKicker::URI::make_read_page_url('/wiki', 'Naney') eq '/wiki/Naney.html');
}

# short_http_url
{
  # host only
  ok(WiKicker::URI::short_http_url('http://www.naney.org', 20)
     eq 'http://www.naney.org');
  ok(WiKicker::URI::short_http_url('http://www.naney.org', 10)
     eq 'http://www.naney.org');

  ok(WiKicker::URI::short_http_url('http://www.naney.org/', 20)
     eq 'http://www.naney.org/');
  ok(WiKicker::URI::short_http_url('http://www.naney.org/', 10)
     eq 'http://www.naney.org/');

  # host + one path
  ok(WiKicker::URI::short_http_url('http://www.naney.org/index.html', 31)
     eq 'http://www.naney.org/index.html');
  ok(WiKicker::URI::short_http_url('http://www.naney.org/index.html', 30)
     eq 'http://www.naney.org/...');

  # long fragment
  ok(WiKicker::URI::short_http_url('http://www.naney.org/index.html#abcd', 36),
     'http://www.naney.org/index.html#abcd');
  ok(WiKicker::URI::short_http_url('http://www.naney.org/index.html#abcd', 35),
     'http://www.naney.org/index.html#...');
  ok(WiKicker::URI::short_http_url('http://www.naney.org/index.html#abcd', 34),
     'http://www.naney.org/...');

  ok(WiKicker::URI::short_http_url('http://www.naney.org/misc/index.html', 30),
     'http://www.naney.org/misc/...');
  ok(WiKicker::URI::short_http_url('http://www.naney.org/abcdef/g.html', 31)
     eq 'http://www.naney.org/.../g.html');
  ok(WiKicker::URI::short_http_url('http://www.naney.org/a/b?abcdefghi', 29)
     eq 'http://www.naney.org/a/b?...');
  ok(WiKicker::URI::short_http_url('http://www.naney.org/a/b?abcdefghi', 28)
     eq 'http://www.naney.org/a/b?...');
  ok(WiKicker::URI::short_http_url('http://www.naney.org/comp/distrib/mknmz-wwwoffle/', 40)
     eq 'http://www.naney.org/.../mknmz-wwwoffle/');

  ok(WiKicker::URI::short_http_url('http://www.city.minami-alps.yamanashi.jp/', 40)
     eq 'http://www.city.minami-alps.yamanashi.jp/');
}

# is host only URI
{
  ok(WiKicker::URI::is_host_only_uri(URI->new('http://www.naney.org')));
  ok(WiKicker::URI::is_host_only_uri(URI->new('http://www.naney.org/')));
  ok(!WiKicker::URI::is_host_only_uri(URI->new('http://www.naney.org/a')));
  ok(!WiKicker::URI::is_host_only_uri(URI->new('http://www.naney.org/#a')));
  ok(!WiKicker::URI::is_host_only_uri(URI->new('http://www.naney.org/?a')));
}

{
  ok(WiKicker::URI::make_read_page_url('http://www.naney.org/wiki', 'TestPage')
     eq 'http://www.naney.org/wiki/TestPage.html');

  ok(WiKicker::URI::make_read_page_url('http://www.naney.org/wiki', 'RssPage')
     eq 'http://www.naney.org/wiki/RssPage');
}
