#
# WiKicker
#
#  WRI-Page.t
#
#
# Copyright (C) 2004,2005 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: WRI-Page.t,v 1.5 2005/04/15 13:11:02 naney Exp $
#
#

use strict;
use Test::More tests => 10;

use Log::Log4perl qw(:easy);
Log::Log4perl->easy_init($ERROR);

use WiKicker::WRI::Factory;
use WiKicker::WRI::Resolver;
use WiKicker::WikiPage::Env;
use WiKicker::PageNameList;
use WiKicker::HTML::LinkMaker;
use WiKicker::CGI::Configuration;

my $factory = WiKicker::WRI::Factory->new;

my $resolver = WiKicker::WRI::Resolver->new;
$resolver->amazon_id('wwwnaneyorg-22');
my $link_maker = WiKicker::HTML::LinkMaker->new(localizer => undef,
                                                timezone => 'GMT',
                                                db => undef,
                                                page_name_list => WiKicker::PageNameList->new,
                                                configuration => WiKicker::CGI::Configuration->new,
                                                script_url => '/wiki',
                                               );
my $wri_env = WiKicker::WikiPage::HtmlEnv->new(resolver => $resolver,
                                               wikicker_url => '/wiki',
                                               wri_factory => $factory,
                                               localizer => undef,
                                               link_maker => $link_maker,
                                              );

# [[page:A]]
{
  my $wri = $factory->create_wri('page:A');
  isa_ok($wri, 'WiKicker::WRI::Page');

  # WRI
  is($wri->original, 'page:A');
  is($wri->to_string, 'page:A');
  ok(! defined($wri->canonical));
  is($wri->to_subject_string, 'A');
  is($wri->to_html('', $wri_env),
     q(<a href="/wiki?edit=A" title="">?</a><span class="DanglingLink">A</span>));
  is($wri->get_link_url, '');
  is($wri->get_image_url, '');

  # QWRN
  is($wri->scheme, 'page');
  is($wri->rest, 'A');
}
