#
# WiKicker
#
#  WRIResolver.t
#
#
# Copyright (C) 2003 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: WRIResolver.t,v 1.6 2003/11/08 06:44:52 naney Exp $
#
#

use strict;
use Test;

BEGIN { plan tests => 28 }

use WiKicker::WRI::Resolver;
use WiKicker::WRI::Factory;
use WiKicker::WikiPage::Env;

my $factory = WiKicker::WRI::Factory->new;


# ${name}
{
  my $resolver = WiKicker::WRI::Resolver->new;
  $resolver->add_interwiki($factory->create_wri('interwiki:encyclopedia:http://www.naney.org/encyclopedia/${name}.html'));
  my $env = WiKicker::WikiPage::Env->new(resolver => $resolver);

  my $wri = $factory->create_wri('encyclopedia:dog');
  ok(ref $wri eq 'WiKicker::WRI::UWRN');
  ok($wri->get_link_url($env)
     eq 'http://www.naney.org/encyclopedia/dog.html');
  ok($wri->get_image_url($env) eq '');
  ok($wri->to_html('', $env) eq qq(<a href="http://www.naney.org/encyclopedia/dog.html">encyclopedia:dog</a>));
}

# ${name}
{
  my $resolver = WiKicker::WRI::Resolver->new;
  $resolver->add_interwiki($factory->create_wri('interwiki:WikiWikiWeb:http://c2.com/cgi/wiki?${name}'));
  my $env = WiKicker::WikiPage::Env->new(resolver => $resolver);
  my $wri = $factory->create_wri('WikiWikiWeb:DanglingLinks');

  ok ($wri->get_link_url($env) eq 'http://c2.com/cgi/wiki?DanglingLinks');
  ok($wri->to_html('', $env) eq qq(<a href="http://c2.com/cgi/wiki?DanglingLinks">WikiWikiWeb:DanglingLinks</a>));
}

# ${name.euc.uri}
{
  my $resolver = WiKicker::WRI::Resolver->new;
  $resolver->add_interwiki($factory->create_wri('interwiki:YukiWiki:http://www.hyuki.com/yukiwiki/wiki.cgi?${name.euc.uri}'));
  my $env = WiKicker::WikiPage::Env->new(resolver => $resolver);

  my $wri = $factory->create_wri('YukiWiki:カテゴリ機能');
  ok ($wri->get_link_url($env) eq 'http://www.hyuki.com/yukiwiki/wiki.cgi?%a5%ab%a5%c6%a5%b4%a5%ea%b5%a1%c7%bd');
  ok($wri->to_html('', $env) eq qq(<a href="http://www.hyuki.com/yukiwiki/wiki.cgi?%a5%ab%a5%c6%a5%b4%a5%ea%b5%a1%c7%bd">YukiWiki:カテゴリ機能</a>));
}

# ${name}
{
  my $resolver = WiKicker::WRI::Resolver->new;
  $resolver->add_interwiki($factory->create_wri('interwiki:goch2:file:////goch2/${name}'));
  my $env = WiKicker::WikiPage::Env->new(resolver => $resolver);

  my $wri = $factory->create_wri('goch2:book');
  ok ($wri->get_link_url($env) eq 'file:////goch2/book');
  ok($wri->to_html('', $env) eq qq(<a href="file:////goch2/book">goch2:book</a>));
}

# href
{
  my $resolver = WiKicker::WRI::Resolver->new;
  my $env = WiKicker::WikiPage::Env->new(resolver => $resolver);
  my $wri_js = $factory->create_wri('java-script:...');

  ok($wri_js->get_link_url($env) eq '');
  ok($wri_js->get_image_url($env) eq '');
  ok($wri_js->to_html('', $env) eq 'java-script:...');
}

# no ${...}
{
  my $resolver = WiKicker::WRI::Resolver->new;
  $resolver->add_interwiki($factory->create_wri('interwiki:Test:http://www.naney.org/'));
  
  my $env = WiKicker::WikiPage::Env->new(resolver => $resolver);

  my $wri = $factory->create_wri('Test:あ/い+う え');
  ok ($wri->get_link_url($env) eq 'http://www.naney.org/');
}

# ${name}
{
  my $resolver = WiKicker::WRI::Resolver->new;
  $resolver->add_interwiki($factory->create_wri('interwiki:Test:http://www.naney.org/?${name}'));
  
  my $env = WiKicker::WikiPage::Env->new(resolver => $resolver);

  my $wri = $factory->create_wri('Test:あ/い+う え');
  ok ($wri->get_link_url($env) eq 'http://www.naney.org/?あ/い+う え');
}

# ${name.uri}
{
  my $resolver = WiKicker::WRI::Resolver->new;
  $resolver->add_interwiki($factory->create_wri('interwiki:Test:http://www.naney.org/?${name.uri}'));
  
  my $env = WiKicker::WikiPage::Env->new(resolver => $resolver);

  my $wri = $factory->create_wri('Test:あ/い+う え');
  ok ($wri->get_link_url($env) eq 'http://www.naney.org/?%e3%81%82%2f%e3%81%84%2b%e3%81%86%20%e3%81%88');
}

# ${name.path}
{
  my $resolver = WiKicker::WRI::Resolver->new;
  $resolver->add_interwiki($factory->create_wri('interwiki:Test:http://www.naney.org/?${name.path}'));
  
  my $env = WiKicker::WikiPage::Env->new(resolver => $resolver);

  my $wri = $factory->create_wri('Test:あ/い+う え');
  ok ($wri->get_link_url($env) eq 'http://www.naney.org/?%e3%81%82/%e3%81%84+%e3%81%86%20%e3%81%88');
}

# ${name.urlencoded}
{
  my $resolver = WiKicker::WRI::Resolver->new;
  $resolver->add_interwiki($factory->create_wri('interwiki:Test:http://www.naney.org/?${name.urlencoded}'));
  
  my $env = WiKicker::WikiPage::Env->new(resolver => $resolver);

  my $wri = $factory->create_wri('Test:あ/い+う え');
  ok ($wri->get_link_url($env) eq 'http://www.naney.org/?%e3%81%82%2f%e3%81%84%2b%e3%81%86+%e3%81%88');
}

# ${name.PukiWiki1.3}
{
  my $resolver = WiKicker::WRI::Resolver->new;
  $resolver->add_interwiki($factory->create_wri('interwiki:Test:http://www.naney.org/?${name.PukiWiki1.3}'));
  
  my $env = WiKicker::WikiPage::Env->new(resolver => $resolver);

  my $wri = $factory->create_wri('Test:あ/い+う え');
  ok ($wri->get_link_url($env) eq 'http://www.naney.org/?%5b%5b%a4%a2%2f%a4%a4%2b%a4%a6%20%a4%a8%5d%5d');
}

# ${name.euc}
{
  my $resolver = WiKicker::WRI::Resolver->new;
  $resolver->add_interwiki($factory->create_wri('interwiki:Test:http://www.naney.org/?${name.euc}'));
  
  my $env = WiKicker::WikiPage::Env->new(resolver => $resolver);

  my $wri = $factory->create_wri('Test:あ/い+う え');
  ok ($wri->get_link_url($env) eq "http://www.naney.org/?\xa4\xa2\x2f\xa4\xa4\x2b\xa4\xa6\x20\xa4\xa8");
}

# ${name.EUC-JP}
{
  my $resolver = WiKicker::WRI::Resolver->new;
  $resolver->add_interwiki($factory->create_wri('interwiki:Test:http://www.naney.org/?${name.EUC-JP}'));
  
  my $env = WiKicker::WikiPage::Env->new(resolver => $resolver);

  my $wri = $factory->create_wri('Test:あ/い+う え');
  ok ($wri->get_link_url($env) eq "http://www.naney.org/?\xa4\xa2\x2f\xa4\xa4\x2b\xa4\xa6\x20\xa4\xa8");
}

# ${name.euc.uri}
{
  my $resolver = WiKicker::WRI::Resolver->new;
  $resolver->add_interwiki($factory->create_wri('interwiki:Test:http://www.naney.org/?${name.euc.uri}'));
  
  my $env = WiKicker::WikiPage::Env->new(resolver => $resolver);

  my $wri = $factory->create_wri('Test:あ/い+う え');
  ok ($wri->get_link_url($env) eq 'http://www.naney.org/?%a4%a2%2f%a4%a4%2b%a4%a6%20%a4%a8');
}

# ${name.EUC-JP.uri}
{
  my $resolver = WiKicker::WRI::Resolver->new;
  $resolver->add_interwiki($factory->create_wri('interwiki:Test:http://www.naney.org/?${name.euc.uri}'));
  
  my $env = WiKicker::WikiPage::Env->new(resolver => $resolver);

  my $wri = $factory->create_wri('Test:あ/い+う え');
  ok ($wri->get_link_url($env) eq 'http://www.naney.org/?%a4%a2%2f%a4%a4%2b%a4%a6%20%a4%a8');
}

# ${name.euc.urlencoded}
{
  my $resolver = WiKicker::WRI::Resolver->new;
  $resolver->add_interwiki($factory->create_wri('interwiki:Test:http://www.naney.org/?${name.euc.urlencoded}'));
  
  my $env = WiKicker::WikiPage::Env->new(resolver => $resolver);

  my $wri = $factory->create_wri('Test:あ/い+う え');
  ok ($wri->get_link_url($env) eq 'http://www.naney.org/?%a4%a2%2f%a4%a4%2b%a4%a6+%a4%a8');
}

# ${name.EUC-JP.urlencoded}
{
  my $resolver = WiKicker::WRI::Resolver->new;
  $resolver->add_interwiki($factory->create_wri('interwiki:Test:http://www.naney.org/?${name.EUC-JP.urlencoded}'));
  
  my $env = WiKicker::WikiPage::Env->new(resolver => $resolver);

  my $wri = $factory->create_wri('Test:あ/い+う え');
  ok ($wri->get_link_url($env) eq 'http://www.naney.org/?%a4%a2%2f%a4%a4%2b%a4%a6+%a4%a8');
}

# ${name.Shift_JIS}
{
  my $resolver = WiKicker::WRI::Resolver->new;
  $resolver->add_interwiki($factory->create_wri('interwiki:Test:http://www.naney.org/?${name.Shift_JIS}'));
  
  my $env = WiKicker::WikiPage::Env->new(resolver => $resolver);

  my $wri = $factory->create_wri('Test:あ/い+う え');
  ok ($wri->get_link_url($env) eq "http://www.naney.org/?\x82\xa0\x2f\x82\xa2\x2b\x82\xa4\x20\x82\xa6");
}

# ${name.Shift_JIS.uri}
{
  my $resolver = WiKicker::WRI::Resolver->new;
  $resolver->add_interwiki($factory->create_wri('interwiki:Test:http://www.naney.org/?${name.Shift_JIS.uri}'));
  
  my $env = WiKicker::WikiPage::Env->new(resolver => $resolver);

  my $wri = $factory->create_wri('Test:あ/い+う え');
  ok ($wri->get_link_url($env) eq 'http://www.naney.org/?%82%a0%2f%82%a2%2b%82%a4%20%82%a6');
}

# ${name.Shift_JIS.urlencoded}
{
  my $resolver = WiKicker::WRI::Resolver->new;
  $resolver->add_interwiki($factory->create_wri('interwiki:Test:http://www.naney.org/?${name.Shift_JIS.urlencoded}'));
  
  my $env = WiKicker::WikiPage::Env->new(resolver => $resolver);

  my $wri = $factory->create_wri('Test:あ/い+う え');
  ok ($wri->get_link_url($env) eq 'http://www.naney.org/?%82%a0%2f%82%a2%2b%82%a4+%82%a6');
}
