#
# WiKicker
#
#  WikiCgiController.t
#
#
# Copyright (C) 2004,2005 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: WikiCgiController.t,v 1.4 2005/05/10 12:56:53 naney Exp $
#
#

use strict;

use Test;
use Cwd;

BEGIN { plan test => 6 }

use WiKicker::WikiCGI::Controller;



BEGIN {
  unless (-e 't/tmp') {
    mkdir('t/tmp', 0755) || die $!;
  }
  unless (-e 't/tmp/htdocs') {
    mkdir('t/tmp/htdocs', 0755) || die $!;
  }
}

sub setup_env {
  $ENV{REQUEST_METHOD} = 'GET';
  $ENV{SCRIPT_FILENAME} = getcwd() . '/t/tmp/htdocs/wiki';
  $ENV{SCRIPT_NAME} = '/wiki';
}

sub clear_properties_file {
  unlink('t/tmp/htdocs/wiki.properties');
}

sub write_properties_file {
  my $properties = shift;

  open(PROPERTIES, ">t/tmp/htdocs/wiki.properties") || die $!;
  print PROPERTIES $properties;
  close(PROPERTIES);
}

sub run {
  my $factory = shift;

  open(OUT, ">t/tmp/html.txt") || die "Can't open file: $!";
  my $stdin = select(OUT);

  my $controller = &$factory();
  $controller->run;

  select($stdin);
  close(OUT);

  open(HTML, 't/tmp/html.txt') || die "Can't open file: $!";
  my @html = <HTML>;
  close(HTML);

  return \@html;
}

#=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
#    new
#-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
# without argument
# without propeties file.
{
  clear_properties_file();
  setup_env();

  my $html = run(sub { WiKicker::WikiCGI::Controller->new });

  ok(!(grep { /<title>FORUM:/ } @{$html}));
}

#=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
#    new
#-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
# without argument
# with propeties file.
{
  my $properties = <<__ENDSTR__;
wikicker.name: FORUM
__ENDSTR__

  write_properties_file($properties);
  setup_env();

  my $html = run(sub { WiKicker::WikiCGI::Controller->new; });

  # check HTML
  ok(grep { /<title>FORUM:/ } @{$html});

}

#=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
#    new
#-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
# with properties_file option
{
  my $properties = <<__ENDSTR__;
wikicker.name: FORUM2
__ENDSTR__

  write_properties_file($properties);
  setup_env();

  my $html = run(sub {WiKicker::WikiCGI::Controller
      ->new(properties_file => 't/tmp/htdocs/wiki.properties')});

  ok(grep { /<title>FORUM2:/ } @{$html});

}

#=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
#    CreatePage
#-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
# for bug bugreport from masuken
{
  clear_properties_file();
  setup_env();
  $ENV{PATH_INFO} = '/CreatePage.html';

  my $html = run(sub { WiKicker::WikiCGI::Controller->new });

  my $html_string = join('', @$html);
  ok($html_string =~ m|<form.+?>.*<input type="hidden" name="action" value="edit"\s*>.*</form>|is);
}

#=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
#    PreferencePage
#-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
# for bug bugreport from masuken
{
  clear_properties_file();
  setup_env();
  $ENV{PATH_INFO} = '/PreferencePage.html';

  my $html = run(sub { WiKicker::WikiCGI::Controller->new });

  my $html_string = join('', @$html);
  ok($html_string =~ m|<form.+?>.*<input type="hidden" name="name" value="PreferencePage"\s*>.*</form>|is);
}

#=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
#    SearchPage
#-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
# for bug bugreport from masuken
{
  clear_properties_file();
  setup_env();
  $ENV{PATH_INFO} = '/SearchPage.html';

  my $html = run(sub { WiKicker::WikiCGI::Controller->new });

  my $html_string = join('', @$html);
  ok($html_string =~ m|<form.+?>.*<input type="hidden" name="action" value="search"\s*>.*</form>|is);
}
