#
# WiKicker
#
#  WordExtractor.t
#
#
# Copyright (C) 2003 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: WordExtractor.t,v 1.5 2003/07/04 13:47:09 naney Exp $
#
#

use strict;
use Test;

BEGIN { plan tests => 66 }

use WiKicker::Text::WordExtractor;

my $extractor = new WiKicker::Text::WordExtractor;

# no word
{
  my $extractor = new WiKicker::Text::WordExtractor;
  $extractor->set_words([qw(a b)]);
  my $splited = $extractor->split_into_words('def');

  ok(@$splited == 1);
  ok($splited->[0]->[0] == 0);
  ok($splited->[0]->[1] eq 'def');
  ok(!defined $splited->[0]->[2]);
}


# jast, 1 char
{
  my $extractor = new WiKicker::Text::WordExtractor;
  $extractor->set_words([qw(a b)]);
  my $splited = $extractor->split_into_words('a');

  ok(@$splited == 1);
  ok($splited->[0]->[0] == 0);
  ok($splited->[0]->[1] eq 'a');
  ok(!defined $splited->[0]->[2]);
}
  
# jast, 2 char
{
  my $extractor = new WiKicker::Text::WordExtractor;
  $extractor->set_words([qw(ab cd)]);
  my $splited = $extractor->split_into_words('ab');

  ok(@$splited == 1);
  ok($splited->[0]->[0] == 1);
  ok($splited->[0]->[1] eq 'ab');
  ok($splited->[0]->[2] eq 'ab');
}

# head
{
  my $extractor = new WiKicker::Text::WordExtractor;
  $extractor->set_words([qw(a@ cd)]);
  my $splited = $extractor->split_into_words('a@cd');

  ok(@$splited == 2);
  ok($splited->[0]->[0] == 1);
  ok($splited->[0]->[1] eq 'a@');
  ok($splited->[0]->[2] eq 'a@');
  ok($splited->[1]->[0] == 0);
  ok($splited->[1]->[1] eq 'cd');
  ok(!defined $splited->[1]->[2]);
}

# head and last
{
  my $extractor = new WiKicker::Text::WordExtractor;
  $extractor->set_words([qw(a@ cd)]);
  my $splited = $extractor->split_into_words('a@xcd');

  ok(@$splited == 3);
  ok($splited->[0]->[0] == 1);
  ok($splited->[0]->[1] eq 'a@');
  ok($splited->[0]->[2] eq 'a@');
  ok($splited->[1]->[0] == 0);
  ok($splited->[1]->[1] eq 'x');
  ok(!defined $splited->[1]->[2]);
  ok($splited->[2]->[0] == 1);
  ok($splited->[2]->[1] eq 'cd');
  ok($splited->[2]->[2] eq 'cd');
}

# abbrev
{
  my $extractor = new WiKicker::Text::WordExtractor;
  $extractor->set_words([qw(ab/b@ xyz)]);
  my $splited = $extractor->split_into_words('ab@d');

  ok(@$splited == 3);
  ok($splited->[0]->[0] == 0);
  ok($splited->[0]->[1] eq 'a');
  ok(!defined $splited->[0]->[2]);
  ok($splited->[1]->[0] == 1);
  ok($splited->[1]->[1] eq 'b@');
  ok($splited->[1]->[2] eq 'ab/b@');
  ok($splited->[2]->[0] == 0);
  ok($splited->[2]->[1] eq 'd');
  ok(!defined $splited->[2]->[2]);
}

# abbrev
{
  my $extractor = new WiKicker::Text::WordExtractor;
  $extractor->set_words([qw(ab/cd ef/gd)]);
  my $splited = $extractor->split_into_words('x cd y');

  ok(@$splited == 3);
  ok($splited->[0]->[0] == 0);
  ok($splited->[0]->[1] eq 'x ');
  ok(!defined $splited->[0]->[2]);
  ok($splited->[1]->[0] == 1);
  ok($splited->[1]->[1] eq 'cd');
  ok($splited->[1]->[2] eq 'ab/cd');
  ok($splited->[2]->[0] == 0);
  ok($splited->[2]->[1] eq ' y');
  ok(!defined $splited->[2]->[2]);
}

# short abbrev
{
  my $extractor = new WiKicker::Text::WordExtractor;
  $extractor->set_words([qw(ab/c)]);
  my $splited = $extractor->split_into_words('x c y');

  ok(@$splited == 1);
  ok($splited->[0]->[0] == 0);
  ok($splited->[0]->[1] eq 'x c y');
}


# WikiName
{
  my $extractor = new WiKicker::Text::WordExtractor;
  $extractor->set_words([qw(WikiName TestName/TestTest xyz)]);
  
  my $splited = $extractor->split_into_words('ab WikiName xyz TestName/TestTest cd');

  ok(@$splited == 3);
  ok($splited->[0]->[0] == 0);
  ok($splited->[0]->[1] eq 'ab WikiName ');
  ok(!defined $splited->[0]->[2]);
  ok($splited->[1]->[0] == 1);
  ok($splited->[1]->[1] eq 'xyz');
  ok($splited->[1]->[2] eq 'xyz');
  ok($splited->[2]->[0] == 0);
  ok($splited->[2]->[1] eq ' TestName/TestTest cd');
  ok(!defined $splited->[2]->[2]);
}

# right connect
{
  my $extractor = new WiKicker::Text::WordExtractor;
  $extractor->set_words([qw(download)]);
  my $splited = $extractor->split_into_words('I downloaded the driver.');

  ok(@$splited == 1);
  ok($splited->[0]->[0] == 0);
  ok($splited->[0]->[1] eq 'I downloaded the driver.');
  ok(!defined $splited->[0]->[2]);
}
